
Accounting API

Use the accounting API to extract accounting data and for account
validation.

This API consists of the following subroutine and user exit: 

*   GetHistory subroutine
*   llacctval user exit

Job accounting information saved in a history file can also be queried
by using the data access API.


GetHistory subroutine

Use the GetHistory subroutine to process local or global LoadLeveler
history files.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax
 
#include "llapi.h"

int GetHistory(char *filename, int (*func) (LL_job *), int version);

Parameters

filename
   Specifies the name of the history file.

(*func) (LL_job *)
   Specifies the user-supplied function you want to call to process each
   history record. The function must return an integer and must accept
   as input a pointer to the LL_job structure. The LL_job structure is
   defined in the llapi.h file.

version
   Specifies the version of the history record you want to create.
   LL_JOB_VERSION in the llapi.h file creates an LL_job history record.

Description

GetHistory opens the history file you specify, reads one LL_job
accounting record, and calls a user-supplied routine, passing to the
routine the address of an LL_job structure. GetHistory processes all
history records one at a time and then closes the file. Any user can
call this subroutine.

The user-supplied function must include the following files: 

#include <sys/resource.h>
#include <sys/types.h>
#include <sys/time.h>

The ll_event_usage structure is part of the LL_job structure and
contains the following LoadLeveler defined data: 

int event
   Specifies the event identifier. This is an integer whose value is one
   of the following: 

   1        Represents a LoadLeveler-generated event.
   2        Represents an installation-generated event.

char *name
   Specifies a character string identifying the event. This can be one
   of the following: 
   *  An installation generated string that uses the command llctl
      capture eventname.
   *  LoadLeveler-generated strings, which can be the following: 
      *  started
      *  checkpoint
      *  vacated
      *  completed
      *  rejected
      *  removed

Return Values

GetHistory returns a zero when successful.

Error Values

GetHistory returns -1 to indicate that the version is not supported or
that an error occurred opening the history file.

Examples

Makefiles and examples which use this API are located in the
samples/llphist subdirectory of the release directory. The examples
include the executable llpjob, which invokes GetHistory to print every
record in the history file. In order to compile llpjob, the sample
Makefile must update the RELEASE_DIR field to represent the current
LoadLeveler release directory. The syntax for llpjob is: 

llpjob history_file

Where history_file is a local or global history file.


llacctval user exit

Use the llacctval executable to perform account validation.

Syntax

program user_name user_group user_acct# acct1 acct2 ...

Parameters

program
   Is the name of the program that performs the account validation. The
   default is llacctval. The name you specify here must match the value
   specified on the ACCT_VALIDATION keyword in the configuration file.

user_name
   Is the name of the user whose account number you want to validate.

user_group
   Is the login group name of the user.

user_acct#
   Is the account number specified by the user in the job command file.

acct1 acct2 ...
   Are the account numbers obtained from the user stanza in the
   LoadLeveler administration file.

Description

The llacctval user exit compares the account number a user specifies in
a job command file with the account numbers defined for that user in the
LoadLeveler administration file. If the account numbers match, llacctval
returns a value of zero. Otherwise, it returns a nonzero value.

The llacctval user exit is invoked from within the llsubmit command. If
the return code is nonzero, llsubmit does not submit the job.

You can replace llacctval with your own accounting user exit.

To enable account validation, you must specify the following keyword in
the configuration file: 
  
ACCT = A_VALIDATE

To use your own accounting exit, specify the following keyword in the
configuration file: 
  
ACCT_VALIDATION = pathname

where pathname is the name of your accounting exit.

Return Values

If the validation succeeds, the exit status must be zero. If it does not
succeed, the exit status must be a nonzero number.
