
Data access API

Use the data access API to access LoadLeveler data objects and to
retrieve specific data from those objects.

You can use this API to query LoadLeveler daemons for information about:

*  BLUE_GENE (Blue Gene system)
*  CLASSES (job classes)
*  CLUSTER (cluster information)
*  FAIRSHARE (fair share scheduling information)
*  JOBS (job information)
*  MACHINES (machine information)
*  MCLUSTERS (multicluster objects)
*  RESERVATIONS (reservation information)
*  WLMSTAT (AIX Workload Manager)

This API can also be used to query a LoadLeveler history file for
accounting information about JOBS.

The data access API consists of the following subroutines: 

*  ll_deallocate subroutine
*  ll_free_objs subroutine
*  ll_get_data subroutine
*  ll_get_objs subroutine
*  ll_next_obj subroutine
*  ll_query subroutine
*  ll_reset_request subroutine
*  ll_set_request subroutine

Using the data access API

The data access API makes use of a query object to facilitate each
request for LoadLeveler data.

The query object is used to specify the details of each query request
and to manage the list of LoadLeveler objects retrieved. It is
initialized by the ll_query subroutine to specify the kind of
LoadLeveler objects requested and is modified by the ll_set_request and
ll_reset_request subroutines to specify filtering of those objects. It
is then passed to the ll_get_objs and ll_next_obj subroutines to use in
traversing the list of objects. To use this API, you need to call the
subroutines in the following order:

*  Call ll_query to initialize the query object and define the type of
   objects you want to query.
*  Call ll_set_request to filter the objects you want to query.
*  Call ll_reset_request to reset the filter on the objects you want to
   query.
*  Call ll_get_objs to retrieve a list of objects from a LoadLeveler
   daemon or history file.
*  Call ll_get_data to retrieve specific data from an object.
*  Call ll_next_obj to retrieve the next object in the list.
*  Call ll_free_objs to free the list of objects you received.
*  Call ll_deallocate to end the query.

In a multicluster configuration, you need to use the ll_cluster 
subroutine to access data from a remote cluster. The ll_cluster 
subroutine is used to define the cluster prior to any data access 
API calls.

To see code that uses these subroutines, see the topic "Examples of
using the data access API" in LoadLeveler: Using and Administering. For
more information on LoadLeveler objects, see the topic "Understanding
the data access LoadLeveler objects" in TWS LoadLeveler: Using and
Administering.


ll_deallocate subroutine

Use the ll_deallocate subroutine to deallocate the query_element
allocated by the ll_query subroutine.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_deallocate (LL_element *query_element);

Parameters

query_element
   Is a pointer to the LL_element returned by the ll_query function.

Description

query_element is the input field for this subroutine.

Return Values

This subroutine returns a zero to indicate success.

Error Values

-1       You specified a query_element that is not valid.

Related Information

Subroutines: ll_free_objs, ll_get_data, ll_get_objs, ll_next_obj,
ll_query, ll_reset_request, ll_set_request


ll_free_objs subroutine

Use the ll_free_objs subroutine to free all of the LL_element objects in
the query_element list that were obtained by the ll_get_objs subroutine.
You must free the query_element by using the ll_deallocate subroutine.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_free_objs (LL_element *query_element);

Parameters

query_element
   Is a pointer to the LL_element returned by the ll_query function.

Description

query_element is the input field for this subroutine.

Return Values

This subroutine returns a zero to indicate success.

Error Values

-1       You specified a query_element that is not valid.

Related Information

Subroutines: ll_free_objs, ll_get_data, ll_get_objs, ll_query,
ll_reset_request, ll_set_request


ll_get_data subroutine

Use the ll_get_data subroutine to return data from a valid LL_element.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax
  
#include "llapi.h"

int ll_get_data (LL_element *element, enum LLAPI_Specification 
                 specification, void* resulting_data_type);

Parameters

element
   Is a pointer to the LL_element returned by the ll_get_objs
   subroutine.

specification
   Specifies the data field within the data object you want to read.

resulting_data_type
   Is a pointer to the location where you want the data stored. If the
   call returns a nonzero value, an error has occurred and the contents
   of the location are undefined.

Description

Note: Before you use this subroutine, make sure you are familiar with
      the concepts discussed in the topic about the LoadLeveler job
      object model in TWS LoadLeveler: Using and Administering.

object and specification are input fields, while resulting_data_type is
an output field.

The ll_get_data subroutine of the data access API allows you to access
LoadLeveler objects. The parameters of ll_get_data are a LoadLeveler
object (LL_element), a specification that indicates what information
about the object is being requested, and a pointer to the area where the
information being requested should be stored.

If the specification indicates an attribute of the element that is
passed in, the result pointer must be the address of a variable of the
appropriate type, and must be initialized to NULL. The type returned by
each specification is found in the specification tables. If the
specification queries the connection to another object, the returned
value is of type LL_element. You can use a subsequent ll_get_data call
to query information about the new object.

The data type char* and any arrays of type int or char must be freed by
the caller.

LL_element pointers cannot be freed by the caller.

For the specifications, LL_MachineOperatingSystem and
LL_MachineArchitecture, resulting_data_type returns the string "???" if
a query is made before the associated records are updated with their
actual values by the appropriate startd daemons.

Return Values

This subroutine returns a zero to indicate success.

Error Values

-1       You specified an object that is not valid.
-2       You specified an LLAPI_Specification that is not valid.

Related Information

Subroutines: ll_deallocate, ll_free_objs, ll_get_objs, ll_next_obj,
ll_query, ll_reset_request, ll_set_request
 

ll_get_objs subroutine

Use the ll_get_objs subroutine to send a query request to the daemon you
specify along with the request data you specified in the ll_set_request
subroutine. ll_get_objs receives a list of objects matching the request.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

LL_element * ll_get_objs (LL_element *query_element, LL_Daemon 
                          query_daemon, char *hostname,int * 
			  number_of_objs, int * error_code);			  

Parameters

query_element
   Is a pointer to the LL_element returned by the ll_query function.

query_daemon
   Specifies the LoadLeveler daemon you want to query or whether you
   want to query job information stored in a history file. The enum
   LL_Daemon is defined in llapi.h as: 
    
   enum LL_Daemon {LL_STARTD, LL_SCHEDD, LL_CM, LL_MASTER, LL_STARTER, 
                   LL_HISTORY_FILE};

   The following table indicates which daemons respond to which query 
   flags: 

query_daemon summary
+-----------------+--------------------------+------------------------+
| When query_type | query_flags (in          | Responded to by these  |
| (in ll_query)   | ll_set_request) can      | daemons:               |
| is:             | be:                      |                        |
+-----------------+--------------------------+------------------------+
| BLUE_GENE       | QUERY_ALL                | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_BASE_PARTITION  | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_PARTITION       | negotiator (LL_CM)     |
+-----------------+--------------------------+------------------------+
| CLASSES         | QUERY_ALL                | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_CLASS              | negotiator (LL_CM)     |
+-----------------+--------------------------+------------------------+
| CLUSTER         | QUERY_ALL                | negotiator (LL_CM)     |
+-----------------+--------------------------+------------------------+
| FAIRSHARE       | QUERY_ALL                | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_GROUP              | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_USER               | negotiator (LL_CM)     |
+-----------------+--------------------------+------------------------+
| JOBS            | QUERY_ALL                | negotiator (LL_CM),    |
|                 |                          | Schedd (LL_SCHEDD), or |
|                 |                          | history file           |
|                 |                          | (LL_HISTORY_FILE)      |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_JOB             | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_CLASS              | negotiator (LL_CM) or  |
|                 |                          | Schedd (LL_SCHEDD)     |
|                 |--------------------------|------------------------|
|                 | QUERY_ENDDATE            | history file           |
|                 |                          | (LL_HISTORY_FILE)      |
|                 |--------------------------|------------------------|
|                 | QUERY_GROUP              | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_HOST               | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_JOBID              | negotiator (LL_CM) or  |
|                 |                          | Schedd (LL_SCHEDD)     |
|                 |--------------------------|------------------------|
|                 | QUERY_PROCID             | startd (LL_STARTD)     |
|                 |--------------------------|------------------------|
|                 | QUERY_RESERVATION_ID     | negotiator (LL_CM) or  |
|                 |                          | Schedd (LL_SCHEDD)     |
|                 |--------------------------|------------------------|
|                 | QUERY_STARTDATE          | history file           |
|                 |                          | (LL_HISTORY_FILE)      |
|                 |--------------------------|------------------------|
|                 | QUERY_STEPID             | negotiator (LL_CM),    |
|                 |                          | Schedd (LL_SCHEDD), or |
|                 |                          | startd (LL_STARTD)     |
|                 |--------------------------|------------------------|
|                 | QUERY_TOP_DOG            | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_USER               | negotiator (LL_CM) or  |
|                 |                          | Schedd (LL_SCHEDD)     |
+-----------------+--------------------------+------------------------+
| MACHINES        | QUERY_ALL                | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_HOST               | negotiator (LL_CM)     |
+-----------------+--------------------------+------------------------+
| MCLUSTERS       | QUERY_ALL                | Schedd (LL_SCHEDD)     |
+-----------------+--------------------------+------------------------+
| RESERVATIONS    | QUERY_ALL                | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_BASE_PARTITION  | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_GROUP              | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_HOST               | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_RESERVATION_ID     | negotiator (LL_CM)     |
|                 |--------------------------|------------------------|
|                 | QUERY_USER               | negotiator (LL_CM)     |
+-----------------+--------------------------+------------------------+
| WLMSTAT         | QUERY_STEPID             | startd (LL_STARTD)     |
+-----------------+--------------------------+------------------------+

hostname
   Specifies the hostname of the daemon or the history file name to be
   queried. 

   When query_type is JOBS, if query_daemon is: 

   LL_SCHEDD or LL_STARTD
            The local machine is queried if the hostname is NULL.

   LL_CM    The hostname is ignored.

   LL_HISTORY_FILE
            The hostname represents the history file to obtain data
            from. If the hostname is NULL, an error is returned.    

   When query_type is MCLUSTER, the query_daemon must be LL_SCHEDD. If
   you specify NULL for the hostname: 
   *  The cluster specified by the ll_cluster API is the local cluster,
      a configured outbound Schedd daemon for the local cluster is
      queried.
   *  The cluster specified by the ll_cluster API is a remote cluster, a
      configured inbound Schedd daemon for the remote cluster is
      queried.

number_of_objs
   Is a pointer to an integer representing the number of objects
   received from the daemon.

error_code
   Is a pointer to an integer representing the error code issued when
   the function returns a NULL value. For more information, see the
   error value descriptions for this interface.

Description

query_element, query_daemon, and hostname are the input fields for this
subroutine. number_of_objs and error_code are output fields.

Each LoadLeveler daemon returns only the objects that it knows about.

Return Values

This subroutine returns a pointer to the first object in the list. You
must use the ll_next_obj subroutine to access the next object in the
list.

Error Values

This subroutine returns a NULL to indicate failure. The error_code
parameter is set to one of the following:

-1       query_element not valid.
-2       query_daemon not valid.
-3       Cannot resolve hostname.
-4       Request type for specified daemon not valid.
-5       System error.
-6       No valid objects meet the request.
-7       Configuration error.
-9       Connection to daemon failed.
-10      Error processing history file (LL_HISTORY_FILE query only).
-11      History file must be specified in the hostname argument
         (LL_HISTORY_FILE query only).
-12      Unable to access the history file (LL_HISTORY_FILE query only).

Related Information

Subroutines: ll_cluster, ll_deallocate, ll_free_objs, ll_get_data,
ll_next_obj, ll_query, ll_set_request


ll_next_obj subroutine

Use the ll_next_obj subroutine to return the next object in the
query_element list you specify.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

LL_element * ll_next_obj (LL_element *query_element);

Parameters

query_element
   Is a pointer to the LL_element returned by the ll_query function.

Description

query_element is the input field for this subroutine.

Use this subroutine in conjunction with the ll_get_objs subroutine to
"loop" through the list of objects queried.

Return Values

This subroutine returns a pointer to the next object in the list.

Error Values

NULL     Indicates an error or the end of the list of objects.

Related Information

Subroutines: ll_cluster, ll_deallocate, ll_free_objs, ll_get_data,
ll_get_objs, ll_query, ll_set_request


ll_query subroutine

Use the ll_query subroutine to initialize the query object and define
the type of query you want to perform. The LL_element created and the
corresponding data returned by this function is determined by the
query_type you select.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

LL_element * ll_query (enum QueryType query_type);

Parameters

query_type
   Can be: 
   *  BLUE_GENE (to query information about the Blue Gene system)
   *  CLASSES (to query information about job classes)
   *  CLUSTER (to query cluster information)
   *  FAIRSHARE (to query fair share scheduling information)
   *  JOBS (to query job information)
   *  MACHINES (to query machine information)
   *  MCLUSTERS (to query multicluster objects) 

      Multicluster objects only exist when LoadLeveler has a
      multicluster configuration.

   *  RESERVATIONS (to query reservation information)
   *  WLMSTAT (to query AIX Workload Manager)

Description

query_type is the input field for this subroutine.

This subroutine is used in conjunction with other data access
subroutines to query information about job and machine objects. You must
call ll_query prior to using the other data access subroutines.

Return Values

This subroutine returns a pointer to an LL_element object. The pointer
is used by subsequent data access subroutine calls.

Error Values

NULL     The subroutine was unable to create the appropriate pointer.

Related Information

Subroutines: ll_cluster, ll_deallocate, ll_free_objs, ll_get_data,
ll_get_objs, ll_next_obj, ll_reset_request, ll_set_request


ll_reset_request subroutine

Use the ll_reset_request subroutine to reset the request data to NULL
for the query_element you specify.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_reset_request (LL_element *query_element);

Parameters

query_element
   Is a pointer to the LL_element returned by the ll_query function.

Description

query_element is the input field for this subroutine.

This subroutine is used in conjunction with ll_set_request to change the
data requested with the ll_get_objs subroutine.

Return Values

This subroutine returns a zero to indicate success.

Error Values

-1       The subroutine was unable to reset the appropriate data.

Related Information

Subroutines: ll_deallocate, ll_free_objs, ll_get_data, ll_get_objs,
ll_next_obj, ll_query, ll_set_request


ll_set_request subroutine

Use the ll_set_request subroutine to determine the data requested during
a subsequent ll_get_objs call to query specific objects. You can filter
your queries based on the query_type, object_filter, and data_filter you
select.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_set_request (LL_element *query_element, QueryFlags query_flags,
                    char **object_filter, DataFilter data_filter);

Parameters

query_element
   Is a pointer to the LL_element returned by the ll_query subroutine.

query_flags
   The following table provides information on query_type (in ll_query) 
   and related query_flags: 

query_flags summary
+-----------------+--------------------------+------------------------+
| When query_type | query_flags can be:      | Flag description:      |
| (in ll_query)   |                          |                        | 
| is:             |                          |                        |
+-----------------+--------------------------+------------------------+
| BLUE_GENE       | QUERY_ALL                | Query Blue Gene base   |
|                 |                          | partitions, switches,  |
|                 |                          | and wires.             |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_BASE_PARTITION  | Query Blue Gene base   |
|                 |                          | partitions, including  |
|                 |                          | any small partitions   |
|                 |                          | allocated on the base  |
|                 |                          | partition.             |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_PARTITION       | Query partitions       |
|                 |                          | defined on the Blue    |
|                 |                          | Gene system.           |
+-----------------+--------------------------+------------------------+
| CLASSES         | QUERY_ALL                | Query all classes.     |
|                 |--------------------------|------------------------|
|                 | QUERY_CLASS              | Query by LoadLeveler   |
|                 |                          | class.                 |
+-----------------+--------------------------+------------------------+
| CLUSTER         | QUERY_ALL                | Query cluster          |
|                 |                          | information from       |
|                 |                          | central manager.       |
+-----------------+--------------------------+------------------------+
| FAIRSHARE       | QUERY_ALL                | Query returns all      |
|                 |                          | available information. |
|                 |--------------------------|------------------------|
|                 | QUERY_GROUP              | Query by LoadLeveler   |
|                 |                          | group.                 |
|                 |--------------------------|------------------------|
|                 | QUERY_USER               | Query by user ID.      |
+-----------------+--------------------------+------------------------+
| JOBS            | QUERY_ALL                | Query all jobs.        |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_JOB             | Query by bluegene type |
|                 |                          | jobs only.             |
|                 |--------------------------|------------------------|
|                 | QUERY_CLASS              | Query by LoadLeveler   |
|                 |                          | class.                 |
|                 |--------------------------|------------------------|
|                 | QUERY_ENDDATE            | Query by job end       |
|                 |                          | dates. History file    |
|                 |                          | query only.            |
|                 |--------------------------|------------------------|
|                 | QUERY_GROUP              | Query by LoadLeveler   |
|                 |                          | group.                 |
|                 |--------------------------|------------------------|
|                 | QUERY_HOST               | Query by machine name. |
|                 |--------------------------|------------------------|
|                 | QUERY_JOBID              | Query by job ID.       |
|                  --------------------------|------------------------|
|                 | QUERY_PROCID             | Query by process ID of |
|                 |                          | a task of a job step.  |
|                 |--------------------------|------------------------|
|                 | QUERY_RESERVATION_ID     | Query job steps bound  |
|                 |                          | to a particular        |
|                 |                          | reservation.           |
|                 |--------------------------|------------------------|
|                 | QUERY_STARTDATE          | Query by job start     |
|                 |                          | dates. History file    |
|                 |                          | query only.            |
|                 |--------------------------|------------------------|
|                 | QUERY_STEPID             | Query by step ID.      |
|                 |--------------------------|------------------------|
|                 | QUERY_TOP_DOG            | Query by job steps     |
|                 |                          | that are top dogs.     |
|                 |--------------------------|------------------------|
|                 | QUERY_USER               | Query by user ID.      |
+-----------------+--------------------------+------------------------+
| MACHINES        | QUERY_ALL                | Query all machines.    |
|                 |--------------------------|------------------------|
|                 | QUERY_HOST               | Query by machine       |
|                 |                          | names.                 |
+-----------------+--------------------------+------------------------+
| MCLUSTERS       | QUERY_ALL                | Query all              |
|                 |                          | multiclusters.         |
+-----------------+--------------------------+------------------------+
| RESERVATIONS    | QUERY_ALL                | Query all              |
|                 |                          | reservations.          |
|                 |--------------------------|------------------------|
|                 | QUERY_BG_BASE_PARTITION  | Query by Blue Gene     |
|                 |                          | base partitions or all |
|                 |                          | for all base           |
|                 |                          | partitions.            |
|                 |--------------------------|------------------------|
|                 | QUERY_GROUP              | Query by LoadLeveler   |
|                 |                          | group that owns the    |
|                 |                          | reservations.          |
|                 |--------------------------|------------------------|
|                 | QUERY_HOST               | Query by machine name. |
|                 |--------------------------|------------------------|
|                 | QUERY_RESERVATION_ID     | Query by reservation   |
|                 |                          | ID.                    |
|                 |--------------------------|------------------------|
|                 | QUERY_USER               | Query by user ID that  |
|                 |                          | owns the reservations. |
+-----------------+--------------------------+------------------------+
| WLMSTAT         | QUERY_STEPID             | Query by step ID.      |
+-----------------+--------------------------+------------------------+

object_filter
   Specifies search criteria. The value you specify for object_filter is
   related to the value you specify for query_flags as shown in the
   following table: 

object_filter value related to the query flags value
+--------------------------------+------------------------------------+
| If you specify:                | Note:                              |
+--------------------------------+------------------------------------+
| QUERY_ALL                      | You do not need an object_filter.  |
+--------------------------------+------------------------------------+
| QUERY_BG_BASE_PARTITION        | The object_filter must contain a   |
|                                | list of base partition IDs. For    |
|                                | all base partitions, the first     |
|                                | entry in the list must contain the |
|                                | string "all".                      |
+--------------------------------+------------------------------------+
| QUERY_BG_PARTITION             | The object_filter must contain a   |
|                                | list of partition IDs. For all     |
|                                | partitions, the first entry in the |
|                                | list must contain the string       |
|                                | "all".                             |
+--------------------------------+------------------------------------+
| QUERY_CLASS                    | The object_filter must contain a   |
|                                | list of LoadLeveler class names.   |
+--------------------------------+------------------------------------+
| QUERY_GROUP                    | The object_filter must contain a   |
|                                | list of LoadLeveler group names.   |
+--------------------------------+------------------------------------+
| QUERY_HOST                     | The object_filter must contain a   |
|                                | list of LoadLeveler machine names. |
|                                | When the query type is JOBS, the   |
|                                | machine names must be the names of |
|                                | machines to which the jobs are     |
|                                | submitted.                         |
+--------------------------------+------------------------------------+
| QUERY_JOBID                    | The object_filter must contain a   |
|                                | list of job IDs (in the form       |
|                                | host.jobid).                       |
+--------------------------------+------------------------------------+
| QUERY_PROCID                   | The object_filter must contain a   |
|                                | list with a single process ID of a |
|                                | task of a job step.                |
+--------------------------------+------------------------------------+
| QUERY_RESERVATION_ID           | The object_filter must contain a   |
|                                | list of reservation IDs.           |
+--------------------------------+------------------------------------+
| QUERY_STARTDATE or             | The object_filter must contain a   |
| QUERY_ENDDATE                  | list of two start dates or two end |
|                                | dates having the format            |
|                                | MM/DD/YYYY.                        |
+--------------------------------+------------------------------------+
| QUERY_STEPID                   | The object_filter must contain a   |
|                                | list of step IDs (in the form      |
|                                | host.jobid.stepid).                |
+--------------------------------+------------------------------------+
| QUERY_TOP_DOG                  | You do not need an object_filter   |
|                                | for QUERY_TOP_DOG.                 |
+--------------------------------+------------------------------------+
| QUERY_USER                     | The object_filter must contain a   |
|                                | list of user IDs.                  |
+--------------------------------+------------------------------------+
  
   The last entry in the object_filter array must be NULL.

data_filter
   Filters the data returned from the object you query. The value you
   specify for data_filter is related to the value you specify for
   query_type. The data_filter must be ALL_DATA (the default) when: 
   *  You query a history file for job information
   *  You specify JOBS and query_flags QUERY_PROCID
   *  You specify BLUE_GENE, CLASSES, CLUSTER, MACHINES, MCLUSTERS,
      RESERVATIONS, or WLMSTAT

Description

query_element, query_flags, object_filter, and data_filter are the input
fields for this subroutine.

The QUERY_PROCID and QUERY_TOP_DOG flags should not be used in
combination with any other query_flags.

Do not use the QUERY_BG_BASE_PARTITION flag in combination with the
QUERY_HOST flag.

You can request certain combinations of object filters by calling
ll_set_request more than once. When you do this, the query flags you
specify are or-ed together. The following are valid combinations of
object filters: 
*  QUERY_JOBID and QUERY_STEPID: the result is the union of both queries
   and any other query flags (such as, QUERY_HOST) will be ignored
*  QUERY_STARTDATE and QUERY_ENDDATE: the result is the intersection of
   both queries
*  QUERY_HOST, QUERY_USER, QUERY_GROUP, QUERY_CLASS, and
   QUERY_RESERVATION_ID: the result is the intersections of all of the
   queries
*  When the query_type is RESERVATIONS, QUERY_RESERVATION_ID takes
   precedence and any other query flags are ignored (with the exception
   of QUERY_ALL, which always replaces any other query flags).
   QUERY_HOST and QUERY_BG_BASE_PARTITION are mutually exclusive and
   setting one will clear the other.

To query jobs owned by certain users and on specific machines, issue
ll_set_request first with QUERY_USER and the appropriate user IDs, and
then issue it again with QUERY_HOST and the appropriate host names.

For example, suppose you issue ll_set_request with a user ID list of
anton and meg, and then issue it again with a host list of k10n10 and
k10n11. The objects returned are all of the jobs on k10n10 and k10n11
which belong to anton or meg.

Note that if you use two consecutive calls with the same flag, the
second call will replace the previous call.

Also, you should not use the QUERY_ALL flag in combination with any
other flag, since QUERY_ALL will replace any existing requests.

For history file queries, query_flags is restricted to the following:
QUERY_ALL, QUERY_STARTDATE, QUERY_ENDDATE.

Return Values

This subroutine returns a zero to indicate success.

Error Values

-1       You specified a query_element that is not valid.
-2       You specified a query_flag that is not valid.
-3       You specified an object_filter that is not valid.
-4       You specified a data_filter that is not valid.
-5       A system error occurred.

Related Information

Subroutines: ll_cluster, ll_deallocate, ll_free_objs, ll_get_data,
ll_get_objs, ll_next_obj, ll_query, ll_reset_request
