
Fair share scheduling API

Use the fair share scheduling API to perform fair share scheduling
operations.

This API consists of the ll_fair_share subroutine.


ll_fair_share subroutine

Use the ll_fair_share subroutine to allow LoadLeveler administrators to
perform certain fair share scheduling operations.

Library

LoadLeveler API library libllapi.a

Syntax

#include "llapi.h"

int ll_fair_share (int version, LL_element **errOBJ, 
                   LL_fair_share_param *param);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be LL_API_VERSION).

errObj
   Is the address of a pointer to an LL_element. The pointer to
   LL_element must be set to NULL before calling this function. If this
   function fails, the pointer will point to an error object. The error
   messages stored in the error object can be displayed through the
   ll_error function. The caller must free the error object storage
   before reusing the pointer.

param
   Is an input parameter of the address of a LL_fair_share_param
   structure defined in llapi.h. 

   In the LL_fair_share_param structure, the fields are defined as
   follows:    

   int operation
            Specifies an intended operation on fair share scheduling
            with one of the following values: 

            FAIR_SHARE_RESET
                     Indicates that fair share scheduling will be reset
                     either to start from scratch again by erasing all
                     previous historic fair share data, or to start from
                     a previously saved point by reading from a saved
                     data file.

            FAIR_SHARE_SAVE
                     Indicates that a snapshop of the historic fair
                     share data for fair share scheduling will be saved
                     to a file in a specified directory.

   char *savedir
            Specifies the directory for saving a snapshot of the
            historic fair share data for fair share scheduling. The
            directory should be initialized to NULL if not used. A valid
            directory writable by the central manager must be specified
            for the FAIR_SHARE_SAVE operation.

   char *saved_file
            Indicates that the previously saved file will be used in the
            FAIR_SHARE_RESET operation, if specified, to reset fair
            share scheduling to a known point. The file should be
            initialized to NULL if not used.

Description

The ll_fair_share( ) subroutine is the API for the llfs command used to
perform certain fair share scheduling operations.

The ll_fair_share subroutine can be used to reset fair share scheduling
or to save a snapshot of the historic fair share data to a file.

This function is for LoadLeveler administrators and the BACKFILL
scheduler only.

Return Values

API_OK   Request successfully sent to LoadLeveler.
API_CANT_CONNECT
         Failed to connect to a LoadLeveler daemon.
API_SCHEDD_DOWN
         One or more of the LoadLeveler Schedd daemons are down.
API_INPUT_NOT_VALID
         Input data is not valid.
API_NOT_SUPPORTED
         Fair share scheduling is not supported by the scheduler.
API_NO_PERMISSION
         The user does not have permission to perform this operation.
API_CANT_READ_FILE
         The specified file cannot be read.
API_CANT_WRITE_FILE
         Failed to write data to a file.
API_NOT_ENABLED
         Fair share scheduling is not enabled.
API_CANT_TRANSMIT
         A data transmission failure occurred.
API_CONFIG_ERR
         Errors were encountered while processing configuration files.

Related Information

Commands: llfs

Subroutines: ll_error
