
llbind - Bind job steps to a reservation

Use the llbind command to bind job steps to a reservation in
LoadLeveler, or unbind job steps from the reservations to which they
currently belong. The bound job steps will only be scheduled to run on
the nodes reserved by the reservation.

Syntax

llbind { -? | -H | -v | [-q] [-m soft | firm] { -r | -R reservation_ID }
       job_step_list }

Flags

-?       Provides a short usage message.

-H       Provides extended help information.

-v       Displays the name of the command, release number, service
         level, service level date, and lowest level of the operating
         system to run this release.

-q       Specifies quiet mode: print no messages other than error
         messages.

-m soft | firm
         Specifies the type of binding. 

         soft     Indicates soft binding. The bound job steps will be
                  allowed to use the reservation's resources, but will
                  also be considered for scheduling prior to the
                  reservation becoming active. Soft-bound job steps are
                  not limited to running on only the reserved resources,
                  but can be scheduled to run on any available resources
                  in the cluster.

         firm     Indicates firm binding. The bound job steps will only
                  be scheduled to run on the nodes reserved by the
                  reservation, and only during the time that the
                  reservation is active.

-r       Specifies an unbind operation. LoadLeveler eliminates any
         association between the job steps and a reservation.

-R reservation_ID
         Specifies the reservation identifier to be modified. The format
         of a full LoadLeveler reservation identifier is
         [host.]rid[.r[.oid]]. 

         where:
          
         *  host is the name of the machine that assigned the
            reservation identifier.
         *  rid is the number assigned to the reservation when it was
            created. An rid is required.
         *  r indicates that this is a reservation ID (r is optional if
            oid is not specified).
         *  oid is the occurrence ID of a recurring reservation (oid is
            optional).          

         The reservation identifier can be specified in an abbreviated
         form, rid[.r[.oid]], when the command is invoked on the same
         machine that assigned the reservation identifier. In this case,
         LoadLeveler will use the local machine's host name to construct
         the full reservation identifier.

job_step_list
         Is a blank-delimited list of job steps to be bound to the
         reservation or unbound from their respective reservations. The
         name of each job step should be in the form
         [host].jobid[.stepid]. 

         where:
          
         *  host is the name of the machine that assigned the job and
            step identifiers.
         *  jobid is the job number assigned to the job when it was
            submitted.
         *  stepid is the job step number assigned to the job step when
            it was submitted.          

         The job or step identifier can be specified in an abbreviated
         form, jobid or jobid.stepid, when the command is invoked on the
         same machine that assigned the job and step identifiers. In
         this case, LoadLeveler will use the local machine's hostname to
         construct the full job or step identifier.          

         Note: For coscheduled job steps, even if all coscheduled job
               steps are not in the list of targeted job steps, the
               requested command is run on all coscheduled job steps.

Description

The llbind command is for LoadLeveler administrators and owner or users
of a reservation. Regular users can only bind their own job steps to a
reservation that they are allowed to use, while a LoadLeveler
administrator can bind any job steps to any reservation.

Only job steps in an idle-like state can be bound to a reservation. A
job step that is in an idle-like state that is already bound to a
reservation can be bound to a new reservation using the llbind command.
The command will first unbind the job step from the reservation it is
currently bound to and then bind it to the requested reservation.

A Blue Gene job step can only be bound to a reservation with Blue Gene
resources. A non-Blue Gene job step can only be bound to a reservation
with non-Blue Gene resources.

The following conditions will cause the bind or unbind request for a job
step to be ignored: 
*  The job step does not exist.
*  The user is not the owner of the job step or a LoadLeveler
   administrator.
*  The job step is requested to be bound to a specific occurrence of a
   reservation that has already passed.
*  The job step is requested to be bound to a specific occurrence (oid)
   of a reservation that is beyond the reservation's expiration. For
   example, if a reservation occurs daily at 4 p.m. and will expire at 4
   p.m. on Friday, and the oid of that final occurrence is 11, if the
   command llbind -j mystepid -R myresid.r.12 were issued, it would not
   be a valid request because oid 12 would occur on Saturday at 4 p.m.,
   after the reservation was set to expire.
*  The job step is not associated with any reservation for an unbind
   request.
*  Binding a Blue Gene job step to a reservation without Blue Gene
   resources.
*  Binding a non-Blue Gene job step to a reservation with Blue Gene
   resources.

Note: A bind or unbind request for a coscheduled job step applies to all
      of the coscheduled job steps. If any of the coscheduled job steps
      meet one of these conditions, the requested operation will fail.
      The llq -l command can be used to check whether the request is
      successful (see the llq command in TWS LoadLeveler: Using and
      Administering for more information).

If a binding method is not specified, the binding method specified for
the reservation will be used by default.

Job steps bound using the firm binding method will be scheduled to run
only on the reserved resources. The only exception is that the front end
node (FEN) needed by a Blue Gene job step will be satisfied from outside
of the reservation. A reservation for a Blue Gene resource does not
reserve resources for a FEN. The mpirun launch program needs to run on a
front end node.

Job steps bound using the soft binding method can be scheduled to run on
any node. These soft-bound job steps compete for the same resources as
nonbound job steps, but nonbound job steps are not allowed to use any
reserved resources, while soft-bound job steps are allowed to use the
reserved resources. Soft-bound job steps can neither preempt other
running job steps, nor can they be preempted by other steps.

If a job step is bound to a recurring reservation and no occurrence ID
is specified, the job step will be bound to the first occurrence of the
reservation, including a currently active occurrence. When a job step is
bound to a specific occurrence of a reservation, it can be scheduled to
run in that occurrence or any subsequent occurrence. If the job step
cannot be scheduled while the requested reservation occurrence is
active, the job step will automatically be bound to the next reservation
occurrence.

If the step is part of a recurring job, all steps of that job will be
bound to the reservation. If any step of the job cannot be bound (for
example, if a step is already running), the bind request will fail.

Only existing job steps queued in LoadLeveler can be bound to a
reservation through this command. You can set the LL_RES_ID environment
variable to bind an interactive Parallel Operating Environment (POE) job
to a reservation or cause llsubmit to both submit and bind a batch job
to a reservation. For batch jobs, you can set the ll_res_id job command
file keyword instead of setting the LL_RES_ID environment variable.

The same format for the reservation ID is used for the LL_RES_ID
environment variable, the ll_res_id job command file keyword, or the
llbind command -R option. The llqres command can be used to view the
list of job steps bound to the reservation.

When the LL_RES_ID environment variable or the ll_res_id job command
file keyword is used, the binding method cannot be specified and the
binding method specified by the reservation will be used. The binding
method can be changed later using this command provided that the job
step is still idle.

Scale-across steps cannot be bound to reservations.

This command is for the BACKFILL scheduler only.

Examples

1. To request to bind the job step c188f2n01.6.0 to reservation
   c188f1n03.2.r, issue: 

   llbind -R c188f1n03.2.r c188f2n01.6.0

   You should receive a response similar to the following: 

   Request to bind job steps to reservation c188f1n03.2.r has been sent 
   to LoadLeveler

2. To request to unbind the job step c188f2n01.6.0 from the reservation
   to which it is currently bound, issue: 

   llbind -r c188f2n01.6.0

   You should receive a response similar to the following: 

   Request to unbind job steps from their respective reservations has 
   been sent to LoadLeveler.

3. To submit a new job and automatically bind it to a reservation using
   the LL_RES_ID environment variable, issue: 

   LL_RES_ID=c197blade3b11.ppd.pok.ibm.com.1.r llsubmit myjob.cmd    

   You should receive a response similar to the following:    

   llsubmit: The job "c197blade3b11.ppd.pok.ibm.com.3" has been 
             submitted.    

   You can use the llq -l command to verify that the job's steps have
   been bound to the reservation:    

   llq -l c197blade3b11.ppd.pok.ibm.com.3    

   You should receive a response similar to the following:    

   =============== Job Step c197blade3b11.ppd.pok.ibm.com.3.0 ==========
           Job Step Id: c197blade3b11.ppd.pok.ibm.com.3.0
              Job Name: myjob
             Step Name: 0
     Structure Version: 10
                 Owner: llbld
            Queue Date: Mon 11 Aug 2008 11:40:38 AM EDT
                Status: Idle
        Reservation ID: c197blade3b11.ppd.pok.ibm.com.1.r 
     Requested Res. ID:  
             Recurring: False
   ...    

   Note:  Alternatively, the ll_res_id job command file keyword can be
         used instead of the LL_RES_ID environment variable.

4. To bind a job step to the first occurrence of a recurring
   reservation, issue: 

   llbind -R c197blade3b11.ppd.pok.ibm.com.1.r \
          c197blade3b11.ppd.pok.ibm.com.8.0    

   You should receive a response similar to the following:    

   llbind: Request to bind job steps to reservation 
   c197blade3b11.ppd.pok.ibm.com.1.r has been sent to LoadLeveler.    

   You can use the llqres -l command to verify that the step is bound to
   the next occurrence of the reservation:    

   llqres -l -R c197blade3b11.ppd.pok.ibm.com.1.r    

   You should receive a response similar to the following:    

   =============== Reservation c197blade3b11.ppd.pok.ibm.com.1.r.2 =====
                  ID: c197blade3b11.ppd.pok.ibm.com.1.r.2
       Creation Time: Fri 08 Aug 2008 12:55:17 PM EDT
               Owner: llbld
               Group: No_Group
          Start Time: Mon 11 Aug 2008 04:00:00 PM EDT
   
   ...
   
               Nodes: 1
                      c197blade3b11.ppd.pok.ibm.com
           Job Steps: 2
                      c197blade3b11.3.0
                      c197blade3b11.8.0
   --------------------------- Future Occurrences ----------------------
          Expiration: Thu 21 Aug 2008 04:00:00 PM EDT
          Recurrence: 0 16 * * *
                      04:00 PM of
                      every day
          Start Time: (3) (Tue 12 Aug 2008 04:00:00 PM EDT)
                      (4) (Wed 13 Aug 2008 04:00:00 PM EDT)
                      (5) (Thu 14 Aug 2008 04:00:00 PM EDT)
   
   ...
   
           Job Steps: 3
                      c197blade3b11.2.0
                      c197blade3b11.3.0
                      c197blade3b11.8.0

5. To bind a job step to a specific occurrence of a recurring
   reservation, issue: 

   llbind -R c197blade3b11.ppd.pok.ibm.com.2.r.4 \
          c197blade3b11.ppd.pok.ibm.com.13.0    

   You should receive a response similar to the following:    

   llbind: Request to bind job steps to reservation 
   c197blade3b11.ppd.pok.ibm.com.2.r.4 has been sent to LoadLeveler.    

   You can use the llq -l command to verify that the step is bound to
   occurrence 4 of reservation c197blade3b11.ppd.pok.ibm.com.2.r:    

   llq -l c197blade3b11.ppd.pok.ibm.com.13.0    

   You should receive a response similar to the following:    

   =============== Job Step c197blade3b11.ppd.pok.ibm.com.13.0 =========
           Job Step Id: c197blade3b11.ppd.pok.ibm.com.13.0
              Job Name: myjob
             Step Name: 0
     Structure Version: 10
                 Owner: llbld
            Queue Date: Mon 11 Aug 2008 12:24:01 PM EDT
                Status: Idle
        Reservation ID: c197blade3b11.ppd.pok.ibm.com.2.r.4 
     Requested Res. ID:  
             Recurring: False
   ...  

   You can also use the llqres -l command:    

   llqres -l -R c197blade3b11.ppd.pok.ibm.com.2.r    

   You should receive a response similar to the following:    

   =============== Reservation c197blade3b11.ppd.pok.ibm.com.2.r.0 =====
                  ID: c197blade3b11.ppd.pok.ibm.com.2.r.0
       Creation Time: Mon 11 Aug 2008 11:57:41 AM EDT
               Owner: llbld
               Group: No_Group
          Start Time: Mon 11 Aug 2008 06:00:00 PM EDT
   
   ...
   
               Nodes: 1
                      c197blade3b11.ppd.pok.ibm.com
           Job Steps: 0
   --------------------------- Future Occurrences ----------------------
          Expiration: Thu 28 Aug 2008 04:00:00 PM EDT
          Recurrence: 0 18 * * *
                      06:00 PM of
                      every day
          Start Time: (0) (Mon 11 Aug 2008 06:00:00 PM EDT)
                      (1) (Tue 12 Aug 2008 06:00:00 PM EDT)
                      (2) (Wed 13 Aug 2008 06:00:00 PM EDT)
                      (3) (Thu 14 Aug 2008 06:00:00 PM EDT)
                      (4) (Fri 15 Aug 2008 06:00:00 PM EDT)
                      (5) (Sat 16 Aug 2008 06:00:00 PM EDT)
   
   ...
   
           Job Steps: 1
                      c197blade3b11.13.0

6. To submit a new job and automatically bind it to a specific
   occurrence of a recurring reservation using the LL_RES_ID environment
   variable, issue: 

   LL_RES_ID=c197blade3b11.ppd.pok.ibm.com.2.r.4 llsubmit myjob.cmd    

   You should receive a response similar to the following:    

   llsubmit: The job "c197blade3b11.ppd.pok.ibm.com.15" has been 
   submitted.    

   You can use the llq -l command to verify that the step is bound to
   occurrence 4 of reservation c197blade3b11.ppd.pok.ibm.com.2.r:    

   llq -l c197blade3b11.ppd.pok.ibm.com.15.0    

   You should receive a response similar to the following:    

   =============== Job Step c197blade3b11.ppd.pok.ibm.com.15.0 =========
           Job Step Id: c197blade3b11.ppd.pok.ibm.com.15.0
              Job Name: myjob
             Step Name: 0
     Structure Version: 10
                 Owner: llbld
            Queue Date: Mon 11 Aug 2008 12:32:15 PM EDT
                Status: Idle
        Reservation ID: c197blade3b11.ppd.pok.ibm.com.2.r.4 
     Requested Res. ID:  
             Recurring: False
   ...    

   You can also use the llqres -l command:    

   llqres -l -R c197blade3b11.ppd.pok.ibm.com.2.r    

   You should receive a response similar to the following:    

   =============== Reservation c197blade3b11.ppd.pok.ibm.com.2.r.0 =====
                  ID: c197blade3b11.ppd.pok.ibm.com.2.r.0
       Creation Time: Mon 11 Aug 2008 11:57:41 AM EDT
               Owner: llbld
               Group: No_Group
          Start Time: Mon 11 Aug 2008 06:00:00 PM EDT
   
   ...
   
               Nodes: 1
                      c197blade3b11.ppd.pok.ibm.com
           Job Steps: 0
   --------------------------- Future Occurrences ----------------------
          Expiration: Thu 28 Aug 2008 04:00:00 PM EDT
          Recurrence: 0 18 * * *
                      06:00 PM of
                      every day
          Start Time: (0) (Mon 11 Aug 2008 06:00:00 PM EDT)
                      (1) (Tue 12 Aug 2008 06:00:00 PM EDT)
                      (2) (Wed 13 Aug 2008 06:00:00 PM EDT)
                      (3) (Thu 14 Aug 2008 06:00:00 PM EDT)
                      (4) (Fri 15 Aug 2008 06:00:00 PM EDT)
                      (5) (Sat 16 Aug 2008 06:00:00 PM EDT)
   
   ...
   
           Job Steps: 2
                      c197blade3b11.13.0
                      c197blade3b11.15.0

Security

LoadLeveler administrators and users can issue this command.
