
llchres - Change attributes of a reservation

Use the llchres command to change one or more of the attributes of a
LoadLeveler reservation.

Syntax 

llchres  { -? | -H | -v | [-q] [-o] [-t start_time | -t {+|-} minutes]
         [-d [+|-] duration] [-n [+|-] number_of_nodes | -h  free |
         -h [+|-] host_list | -j job_step | -f job_command_file |
         -c number_of_bg_cnodes | -F host_file] [-U [+|- user_list]
         [-G [+|-] group_list] [-s {yes|no}] [-i {yes|no}] [-u user]
         [-g group] [-m binding_method] [-e expiration] -R reservation }

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-q 
   Specifies quiet mode: print no messages other than error messages.

-o 
   Modify only the first occurrence of a recurring reservation; either
   the next occurrence to become active, or if the reservation is
   currently active, the current active occurrence.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-t start_time
   Specifies the start_time for a one-time reservation using the format
   [mm/dd[/[cc]yy]] HH:MM. Hours must be specified using a 24-hour
   clock. When the -o flag is used, the start time of the first
   occurrence of a recurring reservation can be modified using this
   format. 

   For a recurring reservation, start_time is a string that specifies
   when the reservation is to recur. The format of the string is 'minute
   hour day_of_month month day_of_week [[mm/dd[/[cc]yy]] HH:MM]' where
   the first part, 'minute hour day_of_month month day_of_week', is the
   same as the format used by crontab. For each field, lists (for
   example, 1,3,5) and ranges (for example, 1-10) can be specified.    

   The second, optional part, '[mm/dd[/[cc]yy]] HH:MM', is the start of
   the first occurrence and must be consistent with the crontab portion
   of the string. For example, if a reservation is needed at 4 p.m.
   every day, but not starting until December 1st, you would specify: '0
   16 * * * 12/01 16:00'.

-t {+|-} minutes
   Modifies the start time for a reservation using minutes. When minutes
   is preceded by a plus (+) sign or minus (-) sign, the current start
   time is postponed or moved closer, respectively, by the number of
   minutes specified.

-d [+|-] duration
   Specifies a new duration for the reservation in minutes. If duration
   is preceded by a plus (+) sign or minus (-) sign, the current
   duration of the reservation is increased or decreased, respectively,
   by the value specified.

-n [+|-] number_of_nodes
   Specifies a new request for the number of nodes to reserve. If
   number_of_nodes is preceded by a plus (+) sign or minus (-) sign, the
   current number of nodes in the reservation is increased or decreased,
   respectively, by the value specified.

-h free
-h [+|-] host_list
   Specifies a change to the list of machines to be reserved. When a
   blank-delimited host list is specified, it indicates that a new list
   of hosts are to be reserved. Specifying a plus (+) sign before host
   list adds the listed machines to the reservation. Specifying a minus
   (-) sign removes the listed machines from the reservation. Note that
   when a host list is specified, the first character of any host name
   cannot be a plus (+) or minus (-) sign. Specifying the reserved word
   free reserves all machines available for this reservation, which
   currently have an active LoadL_startd daemon. The reservation change
   request will succeed if at least one node can be included in the
   reservation.

-j job_step
   Specifies a new request that a set of nodes or Blue Gene compute
   nodes (C-nodes) that the job step can run on be reserved. The job
   step must be in an idle-like state and takes the form
   [host.]jobid.stepid. 

   where:
    
   *  host is the name of the machine that assigned the step identifier.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.    

   The step identifier can be specified in an abbreviated form,
   jobid.stepid, when the command is invoked on the same machine that
   assigned the step identifier. In this case, LoadLeveler will use the
   local machine's hostname to construct the full step identifier.    

   You must be an administrator or the owner of both the reservation and
   job step to make this request. If the request to modify the
   reservation is successful, the job step will be bound to the
   reservation.

-f job_command_file
   Specifies the full path to a new job_command_file that will be
   submitted and the first job step used to determine what resources to
   reserve. The job identifier of the newly created job will be
   displayed. All job steps will be bound to the reservation, or if the
   modification request fails, will be placed in the NotQueued state.
   The job identifier of the newly created job will be displayed.

-c number_of_bg_cnodes
   Specifies the number of C-nodes to reserve in the Blue Gene system.
   The shape of the allocated resource for a given size cannot be
   guaranteed, but the size of the allocated shape will be no smaller
   than the requested size and will be as close to the requested size as
   possible.

-F host_file
   Specifies the name of a file containing a list of machines to
   reserve. If the full path is not specified, then the current working
   directory is assumed. The format of the file is to have one host name
   per line. It can also contain blank lines and comment lines. Comment
   lines start with a '#'. The machines listed in the host file replace
   all of the machines reserved by the reservation. The reservation
   change request will succeed if at least one node can be included in
   the reservation.

-U [+|-] user_list
   Specifies a new blank-delimited list of users who can use the
   reservation. If the list of users is preceded by a plus (+) sign or
   minus (-) sign, add those users to or remove those users from the
   existing list of users that can use the reservation, respectively.

-G [+|-] group_list
   Specifies a new blank-delimited list of LoadLeveler groups that can
   use the reservation. If the list of groups is preceded by a plus (+)
   sign or minus (-) sign, those groups will be added to or removed from
   the existing list of groups, respectively. The first character of any
   group name cannot be plus (+) sign or minus (-) sign.

-s {yes|no}
   SHARED mode is enabled when the reserved word yes is specified. When
   the reserved word no is specified, SHARED mode is disabled.

-i {yes|no}
   When yes is specified, REMOVE_ON_IDLE mode is enabled. When no is
   specified, REMOVE_ON_IDLE mode is disabled.

-u user
   Specifies a new user ID that will own the reservation.

-g group
   Specifies a new LoadLeveler group that will own the reservation.

-m binding_method
   Specifies the method that will be used when job steps are bound to
   the reservation. Possible options are: 

   firm     Use firm binding by default, but allow soft binding
            (default).

   soft     Use soft binding by default, but allow firm binding.

-e expiration
   Modify the expiration date for a recurring reservation using the
   format [mm/dd[/[cc]yy]] HH:MM. Hours must be specified using a
   24-hour clock.

-R reservation
   Specifies the reservation identifier to be modified. The format of a
   full LoadLeveler reservation identifier is [host.]rid[.r]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional).    

   The reservation identifier can be specified in an abbreviated form,
   rid[.r], when the command is invoked on the same machine that
   assigned the reservation identifier. In this case, LoadLeveler will
   use the local machine's host name to construct the full reservation
   identifier.    

   An occurrence ID cannot be specified by the llchres command. Changes
   apply to all occurrences of the reservation unless the -o flag is
   used to change only the first occurrence. 

Note: When a plus (+) sign or minus (-) sign is used to increase or
      decrease a value, there cannot be spaces between the plus (+) sign
      or minus (-) sign and the value.

Description

The llchres command is for LoadLeveler administrators and the owner of a
reservation. Either all requested changes will be made and a message
indicating the reservation request has been sent will be displayed, or
none of the changes will be made and a message describing the reason for
the failure will be displayed along with the message that the request
was sent. If a connection error occurs and the request cannot be sent, a
message will be displayed.

Note that it is possible for a time out to occur while this command is
waiting for a response from the LoadLeveler central manager. Even if a
time out occurs or the command process is killed, the command may still
succeed. To determine if the request has been granted, issue the llqres
command.

Modification requests are subject to resource availability checks and
reservation policies.

Notes on changing a reservation:

*  Administrators can change the attributes of any reservation,
   including the user ID that owns the reservation, while
   non-administrators can change attributes of only the reservations
   they own and cannot change the reservation owner.
*  A reservation owner who is not a LoadLeveler administrator cannot
   change the start time, duration or reserved resources if the start
   time is not at least later than the current time by the number of
   minutes specified by the RESERVATION_MIN_ADVANCE_TIME keyword.
*  The new reservation start time must be later than the current time by
   at least the amount of time specified by the RESERVATION_SETUP_TIME
   keyword.
*  A reservation in the CANCEL or COMPLETE state cannot be changed.
*  When a reservation is not in the WAITING state, the start time cannot
   be changed.
*  When a reservation is not in the WAITING state, the only ways to
   change reserved nodes are to add a number of nodes, or to add or
   delete a list of nodes. Blue Gene resources cannot be changed for a
   reservation not in the WAITING state.
*  A reserved node with a bound step running cannot be removed from the
   reservation.
*  When changing the reservation duration, the end time of the
   reservation must be later than the current time.
*  You cannot delete all reserved resources from a reservation; a
   reservation must have at least one reserved node or Blue Gene C-node.
*  You cannot add a node that is already reserved to a reservation when
   using llchres -h +host_list.
*  You cannot delete a node that is not reserved from a reservation when
   using llchres -h -host_list.
*  If you want to change the owner of a reservation, the new owner must
   be able to own an additional reservation (max_reservations for the
   user is not specified or if specified, the quota is not used up yet).
   If you want to change the group that owns the reservation, the new
   group must be able to own an additional reservation (max_reservations
   for the group is not specified or if specified, the quota is not used
   up yet). If the change request is granted, the new owner and group
   must have the permission to own a new reservation (they cannot both
   have max_reservations unspecified).
*  A coscheduled job step cannot be specified when using the -j or -f
   flags.
*  You cannot change a reservation to reserve a number of nodes if the
   reservation already has some Blue Gene C-nodes reserved.
*  You cannot change a reservation to reserve a number of Blue Gene
   C-nodes if the reservation already has some nodes reserved.
*  The llchres -s no option will fail for a reservation in the
   Active_Shared (AS) state.
*  Shared mode must be yes for a reservation to change from Active (A)
   state to the AS state. Once the reservation is in the AS state, the
   shared mode cannot be changed again.
*  You cannot use the -j flag to specify a scale-across step.
*  You cannot use the -f flag to specify a scale-across job command
   file.

Notes on changing a recurring reservation: 
*  When changing only one occurrence of a recurring reservation using
   the -o option, the expiration, binding method, owner, and group
   cannot be modified.
*  The start time of the first occurrence of a recurring reservation can
   be modified using -o and -t together only when the first occurrence
   is not already ACTIVE.
*  The start times of all occurrences of a recurring reservation can be
   modified using -t with the crontab format.
*  The expiration of a recurring reservation cannot be modified in a way
   that would cause the reservation to immediately expire. In other
   words, the new expiration time must result in there being at least
   one more occurrence of the reservation.
*  If the recurring reservation is not in the WAITING state, changes
   will apply only to future occurrences of the reservation. The
   occurrence currently in the SETUP or ACTIVE state will not be
   modified unless the -o option is used to specifically change the one
   occurrence.
*  The -e option cannot be used when changing a one-time reservation.

This command is for the BACKFILL scheduler only.

Examples

1. To have reservation c94n16.20.r start an hour later than currently
   scheduled with four fewer nodes, issue: 

   llchres -t +60 -n -4 -R c94n16.20.r

   You should receive a response similar to the following: 

   Request to change reservation c94n16.20.r has been sent to 
   LoadLeveler.

2. To change the duration from 20 to 50 minutes and enable only users
   chris, jay, and dave to use the reservation c94n16.31.r, issue: 

   llchres -U chris jay dave -d 50 -R c94n16.31.r

   You should receive a response similar to the following: 

   Request to change reservation c94n16.31.r has been sent to 
   LoadLeveler

3. To change the number of Blue Gene C-nodes in reservation c94n03.2.r,
   issue: 

   llchres -c 512 -R c94n03.2.r

   You should receive a response similar to the following: 

   Request to change reservation c94n03.2.r has been sent to 
   LoadLeveler.

4. To change the hosts listed in reservation c94n03.55.r using a host
   file, issue: 

   llchres -F myhostlistfile -R c94n03.2.r 

   where myhostlistfile resides in the current directory. 

   myhostlistfile: 
   # This is myhostlistfile
   c94n01 
   c94n03 
   c94n05 
   c94n09

5. To change a reservation using a full path name for a host file,
   issue: 

   llchres -F /tmp/myhostlistfile -R c94n03.2.r

6. To extend the duration of only the next occurrence of the reservation
   by 30 minutes, issue: 

   llchres -o -d +30 -R c94n16.22.r

   You should receive a response similar to the following: 

   Request to change reservation c94n16.22.r has been sent to 
   LoadLeveler.

7. To modify a recurring reservation that starts every Friday at 6 p.m.,
   so that it will start every Friday at 7 p.m. instead, issue: 

   llchres -t '0 19 * * 5' -R c94n16.64.r

   You should receive a response similar to the following: 

   Request to change reservation c94n16.64.r has been sent to 
   LoadLeveler.

Security

LoadLeveler administrators and users can issue this command.
