
llmkres - Make a reservation

Use the llmkres command to create a LoadLeveler reservation. A set of
nodes can be reserved in advance for a period of time to run both
interactive and batch jobs.

Syntax

llmkres  { -? | -H | -v | [-q] -t start_time -d duration 
         { -n number_of_nodes | -h host_list | -h free | -j job_step | 
	 -f job_command_file | -c number_of_bg_cnodes | -F host_file } 
	 [-U user_list] [-G group_list] [-s {yes|no}] [-i {yes|no}] 
	 [-g group] [-m binding_method] [-e expiration] }

Flags 

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-t start_time
   Specifies the start_time for a one-time reservation using the format
   [mm/dd[/[cc]yy]] HH:MM. Hours must be specified using a 24-hour
   clock. 

   For a recurring reservation, start_time is a string that specifies
   when the reservation is to recur. The format of the string is 'minute
   hour day_of_month month day_of_week [[mm/dd[/[cc]yy]] HH:MM]' where
   the first part, 'minute hour day_of_month month day_of_week,'  is the
   same as the format used by crontab. For each field, lists (for
   example, 1,3,5) and ranges (for example, 1-10) can be specified.    

   The second, optional part, '[mm/dd[/[cc]yy]] HH:MM', is the start of
   the first occurrence and must be consistent with the crontab portion
   of the string. For example, if a reservation is needed at 4 p.m.
   every day, but not starting until December 1st, you would specify: '0
   16 * * * 12/01 16:00'.

-d duration
   Specifies the duration of the reservation in minutes.

-n number_of_nodes
   Specifies the number of nodes to reserve. To reserve a number of Blue
   Gene C-nodes, use the -c flag.

-h free
-h host_list
   Specifies a blank-delimited list of machines to reserve. To reserve
   every node in the LoadLeveler cluster, use the -h  host_list flag. If
   any one of the nodes cannot be reserved, the request will fail.
   Specifying the reserved word free reserves all machines available for
   this reservation, which currently have an active LoadL_startd daemon.
   The reservation change request will succeed if at least one node can
   be included in the reservation.

-j job_step
   Specifies a job step whose requirements will be used to determine
   what resources to reserve. The job step must be in an idle-like state
   and takes the form [host.]jobid.stepid. 

   where:
    
   *  host is the name of the machine that assigned the job and step
      identifiers.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.    

   The step identifier can be specified in an abbreviated form,
   jobid.stepid, when the command is invoked on the same machine that
   assigned the step identifier. In this case, LoadLeveler will use the
   local machine's host name to construct the full step identifier.    

   You must be an administrator or the job step owner to make this
   request. If the request to make the reservation is successful, the
   job step will be bound to the reservation. If the request is not
   successful, there is no change to the status of the job step.    

   Note: If the job step is of type blue_gene, then only Blue Gene
         compute nodes (C-nodes) will be reserved to satisfy the Blue
         Gene resource requirements of the job step.

-f job_command_file
   Specifies the path to a job_command_file that will be submitted and
   the first job step used to determine what resources to reserve. All
   job steps will be bound to the reservation, or if the reservation
   request fails, be placed in the NotQueued state. The job ID of the
   newly created job will be displayed.

-c number_of_bg_cnodes
   Specifies the number of C-nodes to reserve in the Blue Gene system.
   The shape of the allocated resource for a given size cannot be
   guaranteed, but the size of the allocated shape will be no smaller
   than the requested size and will be as close to the requested size as
   possible.

-F host_file
   Specifies the name of a file containing a list of machines to
   reserve. If the full path is not specified, then the current working
   directory is assumed. The format of the file is to have one host name
   per line. It can also contain blank lines and comment lines. Comment
   lines start with a '#'. If any one of the nodes cannot be reserved,
   the request will fail.

-U user_list
   Specifies a blank-delimited list of users who can use the
   reservation.

-G group_list
   Specifies a blank-delimited list of LoadLeveler groups whose users
   can use the reservation.

-s {yes|no}
   Specifies if the SHARED option is selected for the reservation. For a
   SHARED reservation, after all bound job steps that can run on the
   reserved nodes are scheduled to run, the remaining resources can be
   used to run job steps not bound to the reservation. Only bound job
   steps can be scheduled to run on a reservation that is not shared.
   The default is not to share the reservation.

-i {yes|no}
   Specifies if the REMOVE_ON_IDLE option is selected for the
   reservation. For a REMOVE_ON_IDLE reservation, if all bound job steps
   are finished or if all bound job steps are Idle and none can run on
   the reserved nodes, the reservation will be removed (canceled)
   automatically by LoadLeveler. If this option is not set, the
   reservation will remain, regardless of whether is it is being used or
   not. The default is not to remove the reservation automatically. When
   the REMOVE_ON_IDLE option is used with a recurring reservation, only
   the active occurrence will be removed once the conditions are met for
   that single occurrence.

-g group
   Specifies a LoadLeveler group that will own the reservation. The
   default is what is specified as the default_group in the user stanza
   or No_Group. Ownership of a reservation by a group does not imply
   that all of the members of the group can use the reservation, but
   rather is used as a count toward the maximum number of reservations
   that a group can own.

-m binding_method
   Specifies the method that will be used when job steps are bound to
   the reservation. Possible options are: 

   firm     Use firm binding by default, but allow soft binding
            (default).

   soft     Use soft binding by default, but allow firm binding.

-e expiration
   Specifies the expiration date for a recurring reservation using the
   format [mm/dd[/[cc]yy]] HH:MM. Hours must be specified using a
   24-hour clock.

Description

The llmkres command is for users authorized by LoadLeveler
administrators. The user ID requesting the creation of a reservation
becomes the owner of the reservation and can use the reservation. A
unique reservation ID will be displayed upon successful creation of the
reservation, otherwise a message will be printed out to indicate a
failure.

Note that it is possible for a time out to occur while this command is
waiting for a response from the LoadLeveler central manager. Even if a
time out occurs or the command process is killed, the command may still
succeed. To determine if the request has been granted, issue the llqres
command.

The owner of a reservation maintains certain privileges beyond those
allowed for users of the reservation. The owner of a reservation and
LoadLeveler administrators can always use the reservation. The owner of
a reservation (and the LoadLeveler administrator) can cancel or change a
reservation. Users of a reservation are allowed to bind their jobs to a
reservation. When a reservation is created, the -U and -G flag can be
used to specify who can use the reservation.

For additional information on running interactive jobs with
reservations, see the "Building and submitting jobs" topic in TWS
LoadLeveler: Using and Administering.

This command is for the BACKFILL scheduler only.

A coscheduled job step cannot be specified when using the -j or -f
flags.

A scale-across job step cannot be specified when creating a reservation.

A job step that requests a size that fits into the size of a Blue Gene
reservation might not always be able to run inside the reservation
because of the internal topology of the Blue Gene system. For example,
if a Blue Gene reservation was created using a Blue Gene job that
requested 1024 compute nodes with a connection type of MESH, then a job
requesting 1024 compute nodes with a connection type of TORUS will not
be able to run inside that reservation.

When a Blue Gene reservation is made using a job step that requests a
predefined partition through the bg_partition keyword, resources exactly
the same as in the predefined partition are reserved. The reserved
resources will not change even if the predefined partition is changed to
contain a different set of resources. LoadLeveler selects resources to
reserve in all other cases when the bg_partition keyword is not used.
The field BG Partition in the llqres -l output shows the name of the
predefined partition if any is used to select reserved resources.

Notes on recurring reservations: 
*  The reservation will not be created unless all occurrences of a
   recurring reservation can be honored.
*  The last occurrence of a recurring reservation is the last one to
   start before the expiration date, regardless of the time it will
   complete.
*  Occurrences of the same reservation cannot overlap with one another.
   The difference in start times between two occurrences of a recurring
   reservation must be at least as much as the duration plus the setup
   time.
*  The first occurrence of a recurring reservation will start at the
   earliest time matching the description provided with the -t flag, and
   after RESERVATION_MIN_ADVANCE_TIME.
*  The -e flag cannot be used when creating a one-time reservation.

Examples

1. To reserve 3 nodes for 2 hours starting at 2 p.m. of the current year
   allowing members of the LoadLeveler group loadlusr to use the
   reservation, issue: 

   llmkres -t 01/16 14:00 -d 120 -n 3 -G loadlusr

   Note that if you specify a date that has already passed in the
   current year, you must include the year or an error will occur. 

   You should receive a response similar to the following:    

   The reservation c94n16.pok.ibm.com.20.r has been successfully made.

2. To reserve nodes based on the requirements of one user job, issue:   

   llmkres -t 01/16/2008 02:00 -d 420 -f weather.cmd -i yes

   You should receive a response similar to the following: 

   The job "c94n16.pok.ibm.com.25" has been submitted.
   
   The reservation c94n16.pok.ibm.com.31.r has been successfully made.

3. To reserve two nodes for use by the reservation owner and two
   additional users issue: 

   llmkres -t 01/17 13:30 -d 240 -h c94n01 c94n16 -U jay chris

   You should receive a response similar to the following: 

   The reservation c94n16.pok.ibm.com.55.r has been successfully made.

4. To reserve 1024 Blue Gene C-nodes, issue: 

   llmkres -t 18:00 -d 60 -c 1024

   You should receive a response similar to the following: 

   The reservation c94n03.pok.ibm.com.2.r has been successfully made.

5. To create a reservation using a host file, issue: 

   llmkres -t 03/15 15:00 -d 240 -F myhostlistfile

   where myhostlistfile resides in the current directory. 

   myhostlistfile: 
   # This is myhostlistfile 
   c94n01 
   c94n03 
   c94n05 
   c94n09

6. To create a reservation using a full path name for a host file,
   issue: 

   llmkres -t 03/15 15:00 -d 240 -F /tmp/myhostlistfile

7. To reserve 6 nodes every Friday for 2 hours beginning at 6 p.m. from
   now until the end of the year, issue: 

   llmkres -t '0 18 * * 5' -d 120 -n 6 -e 12/31 23:59

   You should receive a response similar to the following: 

   The reservation c94n16.pok.ibm.com.64.r has been successfully made.

8. To reserve 10 nodes every day from 9 a.m. to 10 a.m. from July 1st
   through September 30th, issue: 

   llmkres -t '0 9 * * * 07/01 09:00' -d 60 -n 10 -e 09/30 09:00

   You should receive a response similar to the following: 

   The reservation c94n16.pok.ibm.com.64.r has been successfully made.

Security

LoadLeveler administrators and users can issue this command.
