
llmodify - Change attributes of a submitted job step

Use the llmodify command to change the attributes or characteristics of
a submitted job.

Syntax

llmodify { -? | -H | -v | [-q] [-X cluster_name] | -c consumable_cpus | 
         -m consumable_real_memory | -W wclimit_add_min | -C job_class | 
	 -a account_no | -s q_sysprio | -p {preempt|nopreempt} |
         -k keyword=value } jobstep }

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-X cluster_name
   Specifies the name of a single cluster where the command is to run.
   This flag cannot be specified with the -p, -s, -W, or -x flags.

-c consumable_cpus
   Specifies the consumable CPU value for an idle-like job step. 

   Allows the ConsumableCpus task resource requirement to be reset to
   the specified value. This value can be any integer equal to or
   greater than zero (0) and should follow the rules for the resources
   keyword in the job command file.

-m consumable_real_memory
   Specifies the consumable real memory value for an idle-like job step.   

   Allows the ConsumableMemory task resource requirement to be reset to
   the specified value. No units should be specified, as megabytes (MB)
   is assumed. This value can be any integer greater than zero (0) and
   should follow the rules for the resources keyword in the job command
   file.

-W wclimit_add_min
   Specifies additional time in minutes to add to the wall clock limits
   of a running-like job step. This option is for preventing a job step
   from being killed due to the wall clock limits. This is a LoadLeveler
   administrator only option. 

   Both the hard limit and soft limit are increased by the specified
   value. This value can be any integer greater than 0.    

   The increase will only be effective if a limit was originally set and
   not already exceeded. If you attempt to modify the wall clock limit
   for a job step that is approaching its current wall clock limit, it
   is possible for the current wall clock limit to expire before it can
   be changed.    

   Specifying llmodify -W will fail if the wall clock time of the job
   step is extended beyond the start time of any reservation that
   reserves resources currently used by the job step. The reservations
   in conflict must be canceled before the request to increase the job
   step's wall clock limit can be granted.

-C job_class
   Specifies the job class name. 

   Allows the job class name to be reset to the specified value for an
   idle-like job step. This value can be any string without white
   spaces.    

   The job class for data staging steps cannot be changed using the -C
   flag.

-a account_no
   Specifies the account number. 

   Allows the account number to be reset to the specified value for an
   idle-like job step.

-s q_sysprio
   Specifies the job step priority. 

   This option allows the q_sysprio for a job step to be reset to the
   specified integer value. The new job step priority will be fixed.
   Once the priority has been modified, it will no longer be changed if
   the central manager recalculates priorities. This is a LoadLeveler
   administrator only option.

-p {preempt|nopreempt}
   Specifies whether a job is preemptable or nonpreemptable. 

   No action will be taken when the -p flag is used to allow or disallow
   preemption of a data staging job step.

-k keyword=value
   Modifies keyword to the new value provided. 

   where keyword is one of the following: 

   account_no
            Changes the account number to the specified value for an
            idle-like job step.

   bg_connection
            Changes the connection option of an idle-like Blue Gene job.
            The subsequent value argument must be a string that is
            either TORUS, MESH, or PREFER_TORUS. bg_connection cannot be
            modified if bg_partition is already specified.

   bg_partition
            Changes the requested partition ID of an idle-like Blue Gene
            job. If this value is specified, bg_requirements,
            bg_connection, bg_shape, bg_size, and bg_rotate will be
            reset to their default values.

   bg_requirements
            Changes the memory requirement that a Blue Gene base
            partition in the LoadLeveler cluster must meet to run an
            idle-like Blue Gene job. The subsequent value option must be
            an expression. Memory is the only variable that is
            supported. bg_requirements cannot be modified if
            bg_partition is already specified.

   bg_rotate
            Changes the rotate option of an idle-like Blue Gene job. The
            subsequent value argument must be a string that is either
            True or False. bg_rotate cannot be modified if bg_partition
            is already specified.

   bg_shape Changes the shape of an idle-like Blue Gene job. The
            subsequent value argument must be of the form "XxYxZ", where
            X, Y, and Z are integers in units of the number of base
            partitions. If this value is specified, any value previously
            specified for bg_size or bg_partition will be reset to its
            default value.

   bg_size  Changes the size of an idle-like Blue Gene job. The
            subsequent value argument must be an integer in units of
            compute nodes. If this value is specified, any value
            previously specified for bg_shape or bg_partition will be
            reset to its default value.

   class    Changes the job class name to the specified value for an
            idle-like job step. The value can be any string without
            white spaces.

   cluster_option
            Changes the cluster_option to the specified value for an
            idle-like job. 

            The -k cluster_option modifies the job to be considered for
            scale-across scheduling. When cluster_option=scale_across is
            specified on a job that is not a scale-across job, the job
            becomes a scale-across job. When cluster_option is specified
            with a value other than scale_across (for example, none),
            the job will no longer be considered a scale-across job.

   consumableCpus
            Changes the ConsumableCpus task resource requirement to the
            specified value. The value can be any integer equal to or
            greater than zero (0).

   consumableMemory
            Changes the ConsumableMemory task resource requirement to
            the specified value. No units should be specified, as
            megabytes (MB) is assumed. This value can be any integer
            greater than zero (0).

   dstg_resources
            Specifies the quantities of the consumable resources
            consumed by each task of the inbound and outbound data
            staging steps of a job. The resources can be machine
            resources or floating resources.

   node_resources = resources_string
            Replaces the node resource requirements specified in the job
            command file at submit time. The entire resource requirement
            must be specified. The rules for the syntax of the
            resources_string are the same as the rules for the
            corresponding job command file keywords. Only a job step in
            an idle-like state can be changed. Any resource requirement
            that was originally specified and is omitted from this
            string will be removed from the job step. The command will
            fail if you specify the same resources in both the resources
            and node_resources statements.

   preemptable
            Specifies whether a job is preemptable or nonpreemptable.
            The value must be either yes or no.

   resources = resources_string
            Replaces the task resource requirements specified in the job
            command file at submit time. The entire resource requirement
            must be specified. The rules for the syntax of the
            resources_string are the same as the rules for the
            corresponding job command file keywords. Only a job step in
            an idle-like state can be changed. Any resource requirement
            that was originally specified and is omitted from this
            string will be removed from the job step. The command will
            fail if you specify the same resources in both the resources
            and node_resources statements. 

            For example: 

            *  If you requested "resources = ConsumableCpus(1)
               ConsumableMemory(1024mb) ConsumableVirtualMemory(2048mb)"
               at submit time and want to modify it, issue: 

               llmodify -k "resources = ConsumableCpus(1) \
	                ConsumableMemory(1024mb) \
                        ConsumableVirtualMemory(4096mb)"

            *  If you requested "node_resources = ConsumableCpus(2)" at
               submit time, an attempt to change the request using
               llmodify -k "resources = ConsumableCpus(1)" will fail.
               You must first remove the node_resources requirement by
               issuing llmodify -k "node_resources = ", then reissue the
               llmodify command to set a new requirement. 

               In this example, if consumable resources are being
               enforced and ENFORCE_RESOURCE_SUBMISSION is true, the job
               step will be placed in the system hold state after the
               first llmodify is issued and will remain in that state
               until another llmodify is issued to set consumable
               resources such that the enforced requirements are met.

   sysprio  Changes the q_sysprio for a job step to the specified
            integer value. The new job step priority will be fixed. This
            is a LoadLeveler administrator only option.

   wclimit_add
            Increases the wall clock limit of a running-like job step by
            the number of specified minutes. This is a LoadLeveler
            administrator only option.

jobstep
   Is the name of a job step to be modified. 

   The format of a full LoadLeveler step identifier is
   host.jobid.stepid.    

   where:
    
   *  host is the name of the machine that assigned the job and step
      identifiers.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.    

   The step identifier can be specified in an abbreviated form,
   jobid.stepid, when the command is invoked on the same machine that
   assigned the step identifier. In this case, LoadLeveler will use the
   local machine's hostname to construct the full step identifier.

Description

All options are for the job step owner or a LoadLeveler administrator on
an idle-like job step with the following exceptions: 

*  -p, -s, and -W are LoadLeveler administrator only options
*  -W is valid only for a job step in a running-like state

The -k cluster_option modifies the job to be considered for scale-across
scheduling. When cluster_option=scale_across is specified on a job that
is not a scale-across job, the job becomes a scale-across job. When
cluster_option is specified with a value other than scale_across (for
example, none), the job will no longer be considered a scale-across job.

The llmodify command cannot remove the scale_across cluster_option from
a scale-across job that is being scheduled by the main scale-across
cluster.

The -C job_class (or -k class) and -s q_sysprio (or -k sysprio) options
are the only ones that support scale-across jobs with the exception of
the cluster_option. If either option is used for a scale-across job, the
modification is applied to the local cluster (the cluster from which the
command is issued). When applied to the local cluster, administrators
can change a scale-across step priority or move a scale-across step to a
more appropriate class in the local cluster without affecting the job on
other clusters.

A request to mark a job step nonpreemptable will fail if the job step's
expected end time extends into an existing reservation.

At the time a job step is modified, LoadLeveler does not check to make
certain that the job step with the modified values can be scheduled to
run.

To determine if a modification request is successful, issue the llq -x
-l command and check the fields shown in the output.

llmodify options and keywords
+----------------------------------+----------------------------------+
| Options and keywords             | Field to check                   |
+----------------------------------+----------------------------------+
| -a or -k account_no              | Account                          |
+----------------------------------+----------------------------------+
| -C or -k class                   | Class                            |
+----------------------------------+----------------------------------+
| -c or -k consumableCpus          | Resources                        |
+----------------------------------+----------------------------------+
| -k bg_connection                 | Wiring Requested                 |
+----------------------------------+----------------------------------+
| -k bg_partition                  | Partition Requested              |
+----------------------------------+----------------------------------+
| -k bg_requirements               | BG Requirements                  |
+----------------------------------+----------------------------------+
| -k bg_rotate                     | Rotate                           |
+----------------------------------+----------------------------------+
| -k bg_shape                      | Shape Requested                  |
+----------------------------------+----------------------------------+
| -k bg_size                       | Size Requested                   |
+----------------------------------+----------------------------------+
| -k cluster_option                | Cluster Option                   |
+----------------------------------+----------------------------------+
| -k dstg_resources                | Resources                        |
+----------------------------------+----------------------------------+
| -k node_resources                | Node Resources                   |
+----------------------------------+----------------------------------+
| -k resources                     | Resources                        |
+----------------------------------+----------------------------------+
| -m or -k consumableMemory        | Resources                        |
+----------------------------------+----------------------------------+
| -p or -k preemptable             | Preemptable                      |
+----------------------------------+----------------------------------+
| -s or -k priority                | q_sysprio                        |
+----------------------------------+----------------------------------+
| -W or -k wclimit_add             | Wall Clk Hard Limit/Wall Clk     |
|                                  | Soft Limit                       |
+----------------------------------+----------------------------------+

An idle-like state is one of the following job states: 
*  Idle
*  Deferred
*  User Hold
*  System Hold
*  User & System Hold
*  Not Queued
*  Vacated
*  Rejected

A running-like state is one of the following job states: 
*  Checkpointing
*  Pending
*  Preempted
*  Preempt Pending
*  Resume Pending
*  Running
*  Starting

Examples

1. This example puts the job step c163n07.12.0 in a nonpreemptable
   state: 

   llmodify -p nopreempt c163n07.12.0

2. To extend the wall clock limits of job step c163n07.12.0 by 30
   minutes: 

   llmodify -W 30 c163n07.12.0

3. To change the shape of job step c193n04.11.0 to 4x5x4 base
   partitions: 

   llmodify -k bg_shape=4x5x4 c193n04.11.0

4. To change the connection type of job step c193n04.11.0 to MESH: 

   llmodify -k bg_connection=MESH c193n04.11.0

5. This example changes the ConsumableCpus resource requirement of job
   step c188f2n08.15.0 in cluster1 to the value 3: 

   llmodify -X cluster1 -c 3 c188f2n08.15.0 

6. To have mystepid be considered for scale-across scheduling, issue: 

   llmodify -k cluster_option=scale_across mystepid

Results

The following shows a sample system response for llmodify -s 109
c163n07.12.0: 

llmodify: request has been sent to LoadLeveler.

llmodify returns the following exit values: 

0        The command ran successfully.
-1       An error occurred.

Security

LoadLeveler administrators and users can issue this command.
