
llqres - Query a reservation

Use the llqres command to return information about reservations in
LoadLeveler.

Syntax 

llqres   { -? | -H | -v | -W | [-l | -r] [-s] [[-u user_list] 
         [-g group_list] [-h host_list | -h all] 
	 [-B base_partition_list | -B all] [-b begin_time]
         [-e end_time] | -R reservation_list] }

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-l 
   Specifies that a long listing be generated for each reservation to be
   queried.

-r 
   Specifies raw mode for output. Each reservation will occupy one line
   with the output fields separated by an exclamation point (!).

-s 
   Specifies that short host names will be used in the output of machine
   names.

-u user_list
   Specifies a blank-delimited list of users. Reservations to be queried
   are owned by one of these users.

-g group_list
   Specifies a blank-delimited list of LoadLeveler groups. Reservations
   to be queried are owned by one of these groups.

-h all
-h host_list
   Specifies a blank-delimited list of machines or all machines.
   Reservations to be queried use one or more of these machines.

-B all
-B base_partition_list
   Specifies all or a blank-delimited list of base partitions in the
   Blue Gene system. Reservations to be queried use one or more of these
   base partitions.

-b begin_time
   Reservations to be queried are active at or after the specified begin
   time. The -b flag can be used together with the -e flag to query
   reservations expected to be active between the begin and end times.
   The begin_time must be specified using the format [mm/dd[/[cc]yy]]
   HH:MM. Hours must be specified using a 24-hour clock.

-e end_time
   Reservations to be queried are active at or before the specified end
   time. The -e flag can be used together with the -b flag to query
   reservations expected to be active between the begin and end times.
   The end_time must be specified using the format [mm/dd[/[cc]yy]]
   HH:MM. Hours must be specified using a 24-hour clock.

-R reservation_list
   Is a blank-delimited list of reservation identifiers to be queried.
   The format of a full LoadLeveler reservation identifier is
   [host.]rid[.r]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional).    

   The reservation identifier can be specified in an abbreviated form,
   rid[.r], when the command is invoked on the same machine that
   assigned the reservation identifier. In this case, LoadLeveler will
   use the local machine's host name to construct the full reservation
   identifier.    

   When -R is specified, -u, -g, and -h are ignored.

Description

All users can issue this command. Reservations satisfying all criteria
specified by -u, -g, -h or -B, -b, and -e will be queried if more than
one of these options are present. The -h and -B flags are mutually
exclusive. No reservation information will be returned if both are
specified at the same time. By default, the llqres command queries all
existing reservations.

This command is for the BACKFILL scheduler only.

Examples

When the BG_ENABLED keyword is set to false in the configuration file,
the following examples apply.

1. When issuing the llqres command, you should receive output similar to
   the following: 

   Id              Owner     ST  Start Time   Duration #Nodes
   -----------     -----     --  -----------  -------- ------
   c94n16.30.r     loadl     A   10/16  14:00    120      3
   c94n16.31.r     dave      W   10/17  02:00    420      4
   c94n16.35.r     carol     W   10/17  13:30    240      2

2. When issuing the llqres -l command, you should receive output similar
   to the following: 

   =============== Reservation c94n16.ppd.pok.ibm.com.64.r =============
   ID: c94n16.ppd.pok.ibm.com.64.r.0
       Creation Time: Mon 25 Feb 10:55:18 AM EST 2008
               Owner: nathan
               Group: No_Group
          Start Time: Sat 01 Mar 07:00:00 PM EST 2008
            Duration: 120 minutes
   Expected End Time: Sat 01 Mar 09:00:00 PM EST 2008
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: nathan
   Modification Time: Mon 25 Feb 10:55:18 AM EST 2008
               Users: 0
              Groups: 0
               Nodes: 4
                      c94n01.ppd.pok.ibm.com
                      c94n02.ppd.pok.ibm.com
                      c94n12.ppd.pok.ibm.com
                      c94n16.ppd.pok.ibm.com
           Job Steps: 1
                      c94n16.ppd.pok.ibm.com.25.0
   ------------------------- Future Occurrences ------------------------
          Expiration: Mon 31 Mar 11:59:00 PM EDT 2008
          Recurrence: 0 19 * * 5-6
                      07:00 PM
                      Friday, Saturday of each week
                      Every month
         Start Times: (1) Sat 01 Mar 07:00:00 PM EST 2008
                      (2) Fri 07 Mar 07:00:00 PM EST 2008
                      (3) Sat 08 Mar 07:00:00 PM EST 2008
                      (4) Fri 14 Mar 07:00:00 PM EDT 2008
                      (5) Sat 15 Mar 07:00:00 PM EDT 2008
                      (6) Fri 21 Mar 07:00:00 PM EDT 2008
                      (7) Sat 22 Mar 07:00:00 PM EDT 2008
                      (8) Fri 28 Mar 07:00:00 PM EDT 2008
                      (9) Sat 29 Mar 07:00:00 PM EDT 2008
       Canceled OIDs: (none)
            Duration: 120 minutes
              SHARED: no
      REMOVE_ON_IDLE: no
               Users: 0
              Groups: 0
           Job Steps: 1
                      c94n16.ppd.pok.ibm.com.25.0 (0)

3. To determine if any reservations will be active on the machine c94n01
   before performing an hours worth of maintenance beginning at 8:00 on
   02/18/2008, issue the following command: 

   llqres -b 02/18/2008 8:00 -e 02/18/2008 9:00 -h c94n01

   You should receive output similar to the following: 

   Id              Owner     ST  Start Time   Duration #Nodes
   -----------     -----     --  -----------  -------- ------
   c94n16.31.r     dave      W   02/18  02:00    420      4

4. There are no job steps associated with a reservation in the following
   example. The short form is used for host names: 

   llqres -r -s -R c94n16.30.r    

   You should receive output similar to the following: 

   c94n16.30.r!Mon Feb 18 08:12:23 EST 2008!loadl!No_Group! 
      Mon Feb 18 14:00:00 EST
   2008!120!Mon Feb 18 16:00:00 EST 2008!no!no!ACTIVE!loadl! 
      Mon Feb 18 10:21:14 EST
   2008!0!!1!loadlusr!3!c94n01,c94n11,c94n12!0!

5. There are job steps associated with a reservation in the following
   example. The short form is used for host names: 

   llqres -r -s -R c94n16.31.r

   You should receive output similar to the following: 

   c94n16.31.r!Mon Feb 18 10:35:18 EST 2008!dave!No_Group! 
      Mon Feb 18 02:00:00 EST
   2008!420!Mon Feb 18 09:00:00 EST 2008!no!yes!WAITING!dave! 
      Mon Feb 18 10:55:18 
   EST 2008!0!!0!!4!c94n01,c94n02,c94n12,c94n16!1!c94n16.25.0

6. To show all reservation occurrences from March 15th 00:01 until the
   reservation expires, issue the following command. Note that the first
   occurrence in this interval is occurrence 4. Of the six job steps
   bound to the reservation, only two of them are bound to occurrence 4
   and are shown in the first section of the listing. All six are shown
   in the second part of the listing. Occurrence 7 has been canceled. It
   is listed as a canceled occurrence under the "Canceled OIDs:" heading
   and is omitted from the list of start times. 

   llqres -l -b 03/15 00:01 -R c94n16.64

   You should receive output similar to the following:
    
   =============== Reservation c94n16.ppd.pok.ibm.com.64.r =============
   ID: c94n16.ppd.pok.ibm.com.64.r.4
       Creation Time: Mon 25 Feb 10:55:18 AM EST 2008
               Owner: nathan
               Group: No_Group
          Start Time: Fri 14 Mar 07:00:00 PM EDT 2008
            Duration: 120 minutes
   Expected End Time: Fri 14 Mar 09:00:00 PM EDT 2008
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: nathan
   Modification Time: Mon 25 Feb 10:55:18 AM EST 2008
               Users: 0
              Groups: 0
               Nodes: 4
                      c94n01.ppd.pok.ibm.com
                      c94n02.ppd.pok.ibm.com
                      c94n12.ppd.pok.ibm.com
                      c94n16.ppd.pok.ibm.com
           Job Steps: 2
                      c94n15.ppd.pok.ibm.com.28.0
                      c94n16.ppd.pok.ibm.com.29.0
   ------------------------- Future Occurrences ------------------------
          Expiration: Mon 31 Mar 11:59:00 PM EDT 2008
          Recurrence: 0 19 * * 5-6
                      07:00 PM
                      Friday, Saturday of each week
                      Every month
         Start Times: (5) Sat 15 Mar 07:00:00 PM EDT 2008
                      (6) Fri 21 Mar 07:00:00 PM EDT 2008
                      (8) Fri 28 Mar 07:00:00 PM EDT 2008
                      (9) Sat 29 Mar 07:00:00 PM EDT 2008
        Canceled OIDs: 7
             Duration: 120 minutes
               SHARED: no
       REMOVE_ON_IDLE: no
                Users: 0
               Groups: 0
            Job Steps: 6
                       c94n15.ppd.pok.ibm.com.28.0 (4)
                       c94n16.ppd.pok.ibm.com.29.0 (4)
                       c94n16.ppd.pok.ibm.com.30.0 (5)
                       c94n16.ppd.pok.ibm.com.30.1 (5)
                       c94n16.ppd.pok.ibm.com.30.2 (5)
                       c94n16.ppd.pok.ibm.com.32.0 (8)

When the BG_ENABLED keyword is set to true in the configuration file,
the following examples apply. 

1. When issuing the llqres command, you should receive output similar to
   the following: 

   llqres
   
   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.62.r     ezhong      W  6/13 18:40        5      1           0
   bgldd1.61.r     ezhong      W  6/13 18:40        5      0         128
   bgldd1.60.r     ezhong      W  6/13 18:30        5      0         512

2. The following example returns reservation information about all
   machines: 

   llqres -h all    

   You should receive output similar to the following: 

   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.62.r     ezhong      W  6/13 18:40        5      1           0

3. The following example generates a list of base partitions for R010: 

   llqres -B R010    

   You should receive output similar to the following: 

   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.60.r     ezhong      A  6/13 18:30        5      0         512

4. The following example generates a list of all base partitions in the
   Blue Gene system in raw mode: 

   llqres -r -B all    

   You should receive output similar to the following: 

   bgldd1.rchland.ibm.com.61.r!Wed 13 Feb 2008 06:28:09 PM CDT! 
      ezhong!No_Group!Wed 13 Feb 2008 06:40:00 PM
   CDT!5!Wed 13 Feb 2008 06:45:00 PM CDT!no!no!WAITING!ezhong! 
      Wed 13 Feb 2008 06:28:09 PM
   CDT!0!!0!!0!!1!bgldd1.rchland.ibm.com.200.0!128!MESH!0x0x0!1!R011 
      (J111;J113;J115;J117)!MYPARTITION
   bgldd1.rchland.ibm.com.60.r!Wed 13 Feb 2008 06:26:36 PM CDT! 
      ezhong!No_Group!Wed 13 Feb 2008 06:30:00 PM
   CDT!5!Wed 13 Feb 2008 06:35:00 PM CDT!no!no!ACTIVE!ezhong! 
      Wed 13 Feb 2008 06:26:36 PM
   CDT!0!!0!!0!!1!bgldd1.rchland.ibm.com.199.0!512!MESH!1x1x1!1!R010!

5. The following example shows a long listing of all reservations in a
   system where Blue Gene support is enabled: 

   llqres -l    

   You should receive output similar to the following:    

   =============== Reservation bgldd1.rchland.ibm.com.62.r =============
                    ID: bgldd1.rchland.ibm.com.62.r
         Creation Time: Wed 13 Feb 2008 06:28:25 PM CDT
                 Owner: ezhong
                 Group: No_Group
            Start Time: Wed 13 Feb 2008 06:40:00 PM CDT
              Duration: 5 minutes
      xpected End Time: Wed 13 Feb 2008 06:45:00 PM CDT
                SHARED: no
          MOVE_ON_IDLE: no
                Status: WAITING
           Modified By: ezhong
     Modification Time: Wed 13 Feb 2008 06:28:25 PM CDT
                 Users: 0
                Groups: 0
                 Nodes: 1
                        bgldd1.rchland.ibm.com
             Job Steps: 1
                        bgldd1.rchland.ibm.com.201.0
            BG C-nodes: 0
         BG Connection:
              BG Shape:
                BG BPs: 0
          BG Partition: 
   =============== Reservation bgldd1.rchland.ibm.com.61.r =============
                    ID: bgldd1.rchland.ibm.com.61.r
         Creation Time: Wed 13 Feb 2008 06:28:09 PM CDT
                 Owner: ezhong
                 Group: No_Group
            Start Time: Wed 13 Feb 2008 06:40:00 PM CDT
              Duration: 5 minutes
     Expected End Time: Wed 13 Feb 2008 06:45:00 PM CDT
                SHARED: no
        REMOVE_ON_IDLE: no
                Status: WAITING
           Modified By: ezhong
     Modification Time: Wed 13 Feb 2008 06:28:09 PM CDT
                 Users: 0
                Groups: 0
                 Nodes: 0
             Job Steps: 1
                        bgldd1.rchland.ibm.com.200.0
            BG C-nodes: 128
         BG Connection: MESH
              BG Shape: 0x0x0
                BG BPs: 1
                        R011(J111;J113;J115;J117)
          BG Partition: MYPARTITION
   =============== Reservation bgldd1.rchland.ibm.com.60.r =============
                    ID: bgldd1.rchland.ibm.com.60.r
         Creation Time: Wed 13 Feb 2008 06:26:36 PM CDT
                 Owner: ezhong
                 Group: No_Group
            Start Time: Wed 13 Feb 2008 06:30:00 PM CDT
              Duration: 5 minutes
     Expected End Time: Wed 13 Feb 2008 06:35:00 PM CDT
                SHARED: no
        REMOVE_ON_IDLE: no
                Status: ACTIVE
           Modified By: ezhong
     Modification Time: Wed 13 Feb 2008 06:26:36 PM CDT
                 Users: 0
                Groups: 0
                 Nodes: 0
             Job Steps: 1
                        bgldd1.rchland.ibm.com.199.0
            BG C-nodes: 512
         BG Connection: MESH
              BG Shape: 1x1x1
                BG BPs: 1
                        R010
          BG Partition: 

6. The following example shows reserving resources during the time
   period from 18:35 to 18:45: 

   llqres -b 18:35 -e 18:45    

   You should receive output similar to the following: 

   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.62.r     ezhong      W  6/13 18:40        5      1           0
   bgldd1.61.r     ezhong      W  6/13 18:40        5      0         128

7. The following example shows one reservation in raw mode. The short
   form is used for hostnames: 

   llqres -r -s c94n16.30.r    

   You should receive output similar to the following: 

   c94n16.30.r!Fri Feb 22 08:12:23 EST 2008!loadl!No_Group! 
      Fri Feb 22 14:00:00 EST
   2008!120!Fri Feb 22 16:00:00 EST 2008!no!no!ACTIVE!loadl! 
      Fri Feb 22 10:21:14 EST
   2008!0!!1!loadlusr!3!c94n01,c94n11,c94n12!0!!0!0x0x0!

8. The following example shows that there are job steps associated with
   the reservation. The short form is used for hostnames: 

   llqres -r -s c94n16.31.r    

   You should receive output similar to the following: 

   c94n16.31.r!Fri Feb 22 10:35:18 EST 2008!dave!No_Group! 
      Thu Feb 21 02:00:00 EST
   2008!420!Thu Feb 21 09:00:00 EST 2008!no!yes!WAITING!dave! 
      Fri Feb 22 10:55:18 EST
   2008!0!!0!!4!c94n01,c94n02,c94n12,c94n16!1!c94n16.25.0!0!0x0x0!

9. To query a recurring reservation with no expiration on a Blue Gene
   system, issue: 

   llqres -l -R bgpdd2sys1.1.r    

   You should receive a response similar to the following:    

   =============== Reservation bgpdd2sys1.rchland.ibm.com.1.r.0 ========
                  ID: bgpdd2sys1.rchland.ibm.com.1.r.0
       Creation Time: Tue 26 Aug 2008 03:30:44 AM CDT
               Owner: yanhy
               Group: yanhy
          Start Time: Mon 01 Sep 2008 08:00:00 AM CDT
            Duration: 10 minutes
   Expected End Time: Mon 01 Sep 2008 08:10:00 AM CDT
              SHARED: no
      REMOVE_ON_IDLE: no
      Binding Method: firm
              Status: WAITING
         Modified By: yanhy
   Modification Time: Tue 26 Aug 2008 03:30:44 AM CDT
               Users: 0
              Groups: 0
               Nodes: 0
           Job Steps: 0
          BG C-nodes: 512
       BG Connection: MESH
            BG Shape: 1x1x1
              BG BPs: 1
                      R20-M1
        BG Partition: 
   --------------------------- Future Occurrences ----------------------
          Expiration: none
          Recurrence: 0-40/20 8-10 1-15/14 * *
                      08:00 AM,08:20 AM,08:40 AM,09:00 AM,09:20 AM,
                      09:40 AM, 10:00 AM,10:20 AM,10:40 AM 
                      day 01,15 of
                      every month
          Start Time: (0) (Mon 01 Sep 2008 08:00:00 AM CDT)
                      (1) (Mon 01 Sep 2008 08:20:00 AM CDT)
                      (2) (Mon 01 Sep 2008 08:40:00 AM CDT)
                      (3) (Mon 01 Sep 2008 09:00:00 AM CDT)
                      (4) (Mon 01 Sep 2008 09:20:00 AM CDT)
                      (5) (Mon 01 Sep 2008 09:40:00 AM CDT)
                      (6) (Mon 01 Sep 2008 10:00:00 AM CDT)
                      (7) (Mon 01 Sep 2008 10:20:00 AM CDT)
                      (8) (Mon 01 Sep 2008 10:40:00 AM CDT)
                      (9) (Mon 15 Sep 2008 08:00:00 AM CDT)
                      (10) (Mon 15 Sep 2008 08:20:00 AM CDT)
                      (11) (Mon 15 Sep 2008 08:40:00 AM CDT)
                      (12) (Mon 15 Sep 2008 09:00:00 AM CDT)
                      (13) (Mon 15 Sep 2008 09:20:00 AM CDT)
                      (14) (Mon 15 Sep 2008 09:40:00 AM CDT)
                      (15) (Mon 15 Sep 2008 10:00:00 AM CDT)
                      (16) (Mon 15 Sep 2008 10:20:00 AM CDT)
                      (17) (Mon 15 Sep 2008 10:40:00 AM CDT)
       Canceled OIDs: (none)
            Duration: 10 minutes
              SHARED: no
      REMOVE_ON_IDLE: no
               Users: 0
              Groups: 0
           Job Steps: 0
