
llrmres - Cancel a reservation

Use the llrmres command to cancel a reservation in LoadLeveler.

Syntax
 
llrmres  { -? | -H | -v | [-q] [-b begin_time] [-e end_time]
         { [-u user_list] [-g group_list] [-h all | -h host_list]
         [-B all | -B base_partition_list] | [-R all | -R
         reservation_list] } }

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-b begin_time
   Indicates that occurrences of a recurring reservation to be canceled
   are active at or after the specified begin time. The -b flag must be
   used together with the -e flag to cancel reservation occurrences
   expected to be active between the begin and end times. The begin_time
   must be specified using the format [mm/dd[/[cc]yy]] HH:MM. Hours must
   be specified using a 24-hour clock.

-e end_time
   Indicates that occurrences of a recurring reservation to be canceled
   are active at or before the specified end time. The -e flag can be
   used together with the -b flag to cancel reservation occurrences
   expected to be active between the begin and end times. The end_time
   must be specified using the format [mm/dd[/[cc]yy]] HH:MM. Hours must
   be specified using a 24-hour clock.

-u user_list
   Specifies a blank-delimited list of user IDs. Reservations to be
   canceled are owned by one of these users.

-g group_list
   Specifies a blank-delimited list of LoadLeveler groups. Reservations
   to be canceled are owned by one of these groups.

-h all
-h host_list
   Specifies a blank-delimited list of machines or all machines.
   Reservations to be canceled use one or more of these machines.

-B all
-B base_partition_list
   Specifies a blank-delimited list of Blue Gene base partitions or all
   Blue Gene base partitions. Reservations to be canceled use one or
   more of these Blue Gene base partitions.

-R all
-R reservation_list
   Is a blank-delimited list of reservation identifiers to be canceled.
   A LoadLeveler administrator can specify the reserved word all to
   cancel all reservations in the system. Nonadministrators can specify
   the reserved word all to cancel all of the reservations that they
   own. The format of a full LoadLeveler reservation identifier is
   [host.]rid[.r[oid]]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional if oid is
      not specified).
   *  oid is the occurrence ID of a recurring reservation (oid is
      optional).    

   The reservation identifier can be specified in an abbreviated form,
   rid[.r[oid]], when the command is invoked on the same machine that
   assigned the reservation identifier. In this case, LoadLeveler will
   use the local machine's host name to construct the full reservation
   identifier.

Description

The llrmres command is for LoadLeveler administrators and owners of a
reservation. Owners of reservations can cancel their own reservations. A
LoadLeveler administrator can cancel any reservation. The state of a job
step will not be changed directly by the cancellation of a reservation.
Reservations satisfying all criteria specified by the -u, -g, -h, -B,
-b, -e, or -R flag will be canceled if more than one of these options
are present. The -h and -B flags are mutually exclusive. The -R flag
cannot be used in conjunction with the -u, -g, -h, or -B flag. The
llqres command can be used to determine the status of the reservation.

When the -b or -e flag is used, all occurrences of recurring
reservations and all one-time reservations that will be active during
the specified interval and that meet the other criteria specified by the
-u, -g, -h, -B, and -R flags are canceled. If all occurrences of a
recurring reservation fall within the specified interval, the entire
reservation is removed.

When the llrmres command is issued against a recurring reservation, the
entire reservation is canceled unless: 
*  The -b and -e flags are used to specify which specific occurrences
   are to be canceled
*  The -R flag is used and the oid is specified

When the -b flag is used, the -e flag must also be used to specify an
end to the interval. If the desired result is for all occurrences that
begin after start_time to be removed, then the way to do this is to
change the reservation's expiration using llchres -e start_time.

The -e flag can be used without the -b flag to remove all occurrences
between now and the specified end_time.

This command is for the BACKFILL scheduler only.

Examples

1. To request to cancel all reservations owned by user ID iris that use
   machine c188f2n01, issue the following command. Note that this
   request can be made either by an administrator or the user iris. 
   llrmres -u iris -h c188f2n01

   You should receive a response similar to the following:
   
   The request to remove reservations has been sent to the central 
   manager.

2. To request that the LoadLeveler administrator cancel all
   reservations, issue: 

   llrmres -R all

   You should receive a response similar to the following: 

   The request to remove reservations has been sent to the central 
   manager.

3. To request that the LoadLeveler administrator cancel all reservations
   of Blue Gene resources, issue: 

   llrmres -B all

   You should receive a response similar to the following: 

   The request to remove reservations has been sent to the central 
   manager.

4. To request that the LoadLeveler administrator cancel all reservations
   on nodes that are not Blue Gene compute nodes (C-nodes), issue: 

   llrmres -h all

   You should receive a response similar to the following: 
   The request to remove reservations has been sent to the central manager.

5. To cancel all occurrences of the recurring reservation c94n16.64.r
   between now (where now is February 23rd) and March 17th, issue: 

   llrmres -e 03/17 23:59 -R c94n16.64.r

6. To cancel all occurrences of all reservations owned by user ID nathan
   during the month of April, issue: 

   llrmres -b 04/01 00:00 -e 04/30 23:59 -u nathan

7. To cancel one specific occurrence of a recurring reservation, issue: 

   llrmres -R c197blade3b11.10.r.16

Security

LoadLeveler administrators and users can issue this command.
