
llsummary - Return job resource information for accounting

Use the llsummary command to return job resource information on
completed jobs for accounting purposes.

Syntax

llsummary  [-?] [-H] [-v] [-x] [-l] [-s MM/DD/YYYY to MM/DD/YYYY]
           [-e MM/DD/YYYY to MM/DD/YYYY] [-g group] [-G unixgroup] 
	   [-a allocated] [-r report] [-j jobname] [-d section] 
	   [-c class] [-u user] [filelist]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-x 
   Provides extended information. Using -x can produce a very long
   report. This option is meaningful only when used with the -l option.
   You must enable the recording of accounting data in order to collect
   information with the -x flag. To do this, specify ACCT=A_ON A_DETAIL
   in your LoadL_config file.

-l 
   Specifies that the long form of output is displayed.

-s 
   Specifies a range for the start date (queue date) for accounting data
   to be included in this report. The report will contain information
   about every job that contains at least one step that falls within the
   specified range. The format for entering the date is either MM/DD/YYYY
   (where MM is month, DD is day, and YYYY is year), MM/DD/YY (where YY
   is a two-digit year value), or a string of digits representing the
   number of seconds since 1970. If a two-digit year value is used, then
   69-99 maps to 1969-1999, and 00-68 maps to 2000-2068. The default is
   to include all the data in the report.

-e 
   Specifies a range for the end date (completion date) for accounting
   data to be included in this report. The report will contain information
   about every job that contains at least one step that falls within the
   specified range. The format for entering the date is either MM/DD/YYYY
   (where MM is month, DD is day, and YYYY is year), MM/DD/YY (where YY
   is a two-digit year value), or a string of digits representing the
   number of seconds since 1970. The default is to include all the data
   in the report.

-u user
   Specifies the user ID for whom accounting data is reported.

-c class
   Specifies the class for which accounting data is reported. For
   reports of all formats (short, long and extended), llsummary will
   report information about every job which contains at least one step
   of the specified class. For the short format, llsummary also reports
   a job count and step count for each class; for these counts, a job's
   class is determined by the class of its first step.

-g group
   Specifies the LoadLeveler group for which accounting data is
   reported. For reports of all formats (short, long and extended),
   llsummary reports information about every job which contains at least
   one step of the specified group. For the short format, llsummary also
   reports a job count and step count for each group; for these counts,
   a job's group is determined by the group of its first step.

-G unixgroup
   Specifies the UNIX group for which accounting data is reported.

-a allocated
   Specifies the hostname that was allocated to run the job. You can
   specify the allocated host in short or long form.

-r report
   Specifies the report type. You must enable the recording of
   accounting data in order to collect information with the -r flag. To
   do this, specify ACCT=A_ON A_DETAIL in your LoadL_config file. You
   can choose one or more of the following reports: 

   avgthroughput
            Provides average queue time, run time, and CPU time for jobs
            that ran for at least some period of time.

   maxthroughput
            Provides maximum queue time, run time, and CPU time for jobs
            that ran for at least some period of time.

   minthroughput
            Provides minimum queue time, run time, and CPU time for jobs
            that ran for at least some period of time.

   numeric  Reports CPU times in seconds rather than hours, minutes, and
            seconds.

   resource Provides CPU usage for all submitted jobs, including those
            that did not run. This is the default.

   throughput
            Selects all throughput reports.

-d section
   Specifies the category (data section) for which you want to generate
   a report. You can specify one or more of the following: user, group,
   unixgroup, class, account, day, week, month, jobid, jobname,
   allocated.

-j host.jobid
   Specifies the job for which accounting data is reported. 

   The format of a full LoadLeveler job identifier is host.jobid.    

   where:
    
   *  host is the name of the machine that assigned the job identifiers.
   *  jobid is the job number assigned to the job when it was submitted.    

   The entire host.jobid string is required.

filelist
   Is a blank-delimited list of files containing the accounting data. If
   not specified, the default is the local history file on the machine
   from which the command was issued. You can use the llacctmrg command
   to combine history files on different Schedd machines into a single
   history file.

Description

You must enable the recording of accounting data in order to generate
any of the four throughput reports. To do this, specify ACCT=A_ON in
your LoadL_config file. For detailed usage of the ACCT keyword, see the
"Gathering job accounting data" topic in TWS LoadLeveler: Using and
Administering.

In order to create an accounting report with the llsummary command, you
must have read access to a history file. If a history file name is not
specified as an argument, llsummary uses the history file in the
LoadLeveler spool directory of the local machine as input. By default,
the permissions of the spool directory are set by the llinit command to
700 at installation time. However, these permissions may be changed by a
system administrators with root privileges.

The file permissions of the history file created by a LoadL_schedd
daemon are controlled by the HISTORY_PERMISSION configuration keyword. A
specification such as HISTORY_PERMISSION = rw-rw-r-- will result in
permission settings of 664. The default settings are 660.

Notes on recurring reservations:

For recurring jobs, an accounting record will be written each the job
completes, meaning that all steps of the job have completed. In the
standard listing, the result is that the accounting data from every
occurrence of the job that is present in the history file used is
included in the summary totals. In the long and extended listings, each
occurrence of each step will be displayed under a single job heading.
Multiple occurrences of the same step can be distinguished by the
Reservation ID field, which will include the occurrence ID as part of
the reservation ID.

Examples

1. The following example requests summary reports (standard listing) of
   all the jobs submitted on your machine between the days of January
   15, 2008 and March 15, 2008: 

   llsummary -s 01/15/2008 to 03/15/2008

2. This example generates the standard listing when you do not specify
   -l, -r, or -d with llsummary. 

   This sample report includes summaries of the following data: 

   *  Number of jobs, Total CPU usage, per user.
   *  Number of jobs, Total CPU usage, per class.
   *  Number of jobs, Total CPU usage, per group.
   *  Number of jobs, Total CPU usage, per account number.    

   llsummary    

   You should receive output similar to the following:            
   
          Name   Jobs   Steps        Job Cpu    Starter Cpu     Leverage
       krystal     15      36     0+00:09:50     0+00:00:10         59.0
        lixin3     18      54     0+00:08:28     0+00:00:16         31.8
         TOTAL     33      90     0+00:18:18     0+00:00:27         40.7
    
         Class   Jobs   Steps        Job Cpu    Starter Cpu     Leverage
         small      9      21     0+00:01:03     0+00:00:06         10.5
         large     12      36     0+00:13:45     0+00:00:11         75.0
          osl2      3       9     0+00:00:27     0+00:00:02         13.5
      No_Class      9      24     0+00:03:01     0+00:00:06         30.2
         TOTAL     33      90     0+00:18:18     0+00:00:27         40.7
    
         Group   Jobs   Steps        Job Cpu    Starter Cpu     Leverage
      No_Group     12      30     0+00:09:32     0+00:00:09         63.6
     chemistry      7      18     0+00:04:50     0+00:00:05         58.0
   engineering     14      42     0+00:03:56     0+00:00:12         19.7
     TOTAL         33      90     0+00:18:18     0+00:00:27         40.7
    
       Account   Jobs   Steps        Job Cpu    Starter Cpu     Leverage
         33333     16      39     0+00:05:54     0+00:00:11         32.2
         22222     15      45     0+00:12:05     0+00:00:13         55.8
         99999      2       6     0+00:00:18     0+00:00:01         18.0
         TOTAL     33      90     0+00:18:18     0+00:00:27         40.7
  
   The standard listing includes the following fields:    

   Account  Account number specified for the jobs.

   Class    Class specified or defaulted for the jobs.

   Group    User's login group.

   Job CPU  Total CPU time consumed by user's jobs.

   Jobs     Count of the total number of jobs submitted by this user,
            class, group, or account.

   Leverage Ratio of job CPU to starter CPU.

   Name     User ID submitting jobs.

   Starter CPU
            Total CPU time consumed by LoadLeveler starter processes on
            behalf of the user jobs.

   Steps    Count of the total number of job steps submitted by this
            user, class, group, or account.

3. To generate a throughput report, issue: 

   llsummary -r throughput    

   You should receive output similar to the following. Note that only
   the user output is shown, the class, group, and account lines are not
   shown.    

      Name   Jobs   Steps   AvgQueueTime    AvgRealTime     AvgCPUTime
     loadl      1       4     0+00:00:03     0+00:05:27     0+00:05:17
     user1      2       6     0+00:03:05     0+00:03:45     0+00:03:04
       ALL      3      10     0+00:01:52     0+00:04:26     0+00:03:58
   
      Name   Jobs   Steps   MinQueueTime    MinRealTime     MinCPUTime
     loadl      1       4     0+00:00:01     0+00:02:49     0+00:02:44
     user1      2       6     0+00:02:02     0+00:03:43     0+00:03:02
       ALL      3      10     0+00:00:01     0+00:02:49     0+00:02:44
   
      Name   Jobs   Steps   MaxQueueTime    MaxRealTime     MaxCPUTime
     loadl      1       4     0+00:00:06     0+00:12:58     0+00:12:37
     user1      2       6     0+00:06:21     0+00:03:48     0+00:03:07
       ALL      3      10     0+00:06:21     0+00:12:58     0+00:12:37
   
   The -r listing includes the following fields:    

   AvgCPUTime
            Average amount of accumulated CPU time for jobs associated
            with this user, class, group, or account.

   AvgQueueTime
            Average amount of time the job spent queued before running
            for this user, class, group, or account.

   AvgRealTime
            Average amount of accumulated wall clock time for jobs
            associated with this user, class, group, or account.

   MaxCPUTime
            Time of the job with the greatest amount of CPU time for
            this user, class, group, or account.

   MaxQueueTime
            Time of the job that spent the greatest amount of time in
            queue before running for this user, class, group, or
            account.

   MaxRealTime
            Time of the job with the greatest amount of wall clock time
            for this user, class, group, or account.

   MinCPUTime
            Time of the job with the least amount of CPU time for this
            user, class, group, or account.

   MinQueueTime
            Time of the job that spent the least amount of time in queue
            before running for this user, class, group, or account.

   MinRealTime
            Time of the job with the least amount of wall clock time for
            this user, class, group, or account.    

   The ALL line for the Average listing displays the average time for
   all users, classes, groups, and accounts. The ALL line for the
   Minimum listing displays the time of the job with the least amount of
   time for all users, classes, groups, and accounts. The ALL line for
   the Maximum listing displays the time of the job with the greatest
   amount of time for all users, classes, groups, and accounts.

4. The following example generates the long listing that contains Blue
   Gene-specific information: 

   llsummary -l -j job_name

   You should receive output similar to the following: 

   .
   .
   .
              Step Type: bluegene
         Min Processors: 1
         Max Processors: 1
         Size Requested: 2048
         Size Allocated: 2048
        Shape Requested:
        Shape Allocated: 32x8x8
       Wiring Requested: PREFER_TORUS
       Wiring Allocated: TORUS
                 Rotate: TRUE
    Partition Requested: 
    Partition Allocated: part130
        BG Requirements: (Memory == 1024)
             Error Text:
      Alloc. Host Count: 1
   .
   .
   .

5. The following example generates the long listing that contains
   multicluster-specific information submitted or moved to a remote
   cluster: 

   llsummary -l 

   You should receive output similar to the following: 

   .
   .
   .
    Scheduling Cluster: cluster1
    Submitting Cluster: cluster2
       Sending Cluster: cluster2
       Submitting User: brownap
        Schedd History: c188f2n08.ppd.pok.ibm.com
      Outbound Schedds: c188f2n08.ppd.pok.ibm.com
   .
   .
   .
    Cluster input file: /u/brownap/copyfile_input, /tmp/copyfile_input1
    Cluster input file: /u/brownap/copyfile_input, /tmp/copyfile_input2
    Cluster input file: /u/brownap/copyfile_input, /tmp/copyfile_input3
   Cluster output file: /tmp/copyfile_output, /u/brownap/copyfile_output
   .
   .
   .
   
   For an explanation of the fields in the long listing, see the llq
   command in TWS LoadLeveler: Using and Administering. See the "Sample
   command output" topic for sample output of long listings in TWS
   LoadLeveler: Using and Administering.

6. For InfiniBand support, the following example includes the port
   number for the allocated hosts and task instances: 

   llsummary -l -x 
   
   You should receive output similar to the following:
    
   .
   .    
   .
   
   Task
   ----
   
      Num Task Inst: 4
      Task Instance: c171f6sq07:0:ib0(MPI,IP,-1,Shared,0 
         rCxt Blks,1), ib1(MPI,IP,-1,Shared,0 rCxt Blks,2)
      Task Instance: c171f6sq07:1:ib0(MPI,IP,-1,Shared,0 
         rCxt Blks,1), ib1(MPI,IP,-1,Shared,0 rCxt Blks,2)
      Task Instance: c171f6sq08:2:ib0(MPI,IP,-1,Shared,0 
         rCxt Blks,1), ib1(MPI,IP,-1,Shared,0 rCxt Blks,2)
      Task Instance: c171f6sq08:3:ib0(MPI,IP,-1,Shared,0 
         rCxt Blks,1), ib1(MPI,IP,-1,Shared,0 rCxt Blks,2)
   .
   .
   .

Security

LoadLeveler administrators and users can issue this command.
