/*======================================================================*/
/*                                                                      */
/* Module Name: myclass.c                                               */
/*                                                                      */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* Description: This sample program uses the Data Access API to query   */
/* the CLASSES object to obtain information about job classes.          */
/*                                                                      */
/*======================================================================*/

#include <stdio.h> 
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include "llapi.h"

extern char *optarg;

#define  STR_NULL(ptr) (ptr? ptr : "")
#define  FORMAT_BOOLEAN(v) ( (v)? "T" : "F")

void usage(void)
{
	printf("Usage: myclass [-l] [-r] [class list]\n");
}

void print_strings(char **ppc)
{
	int i = 0;
	if (!ppc) return;
	while (ppc[i]) {
		printf(" %s", ppc[i]);
		i++;
	}
	printf("\n");
}

int free_strings(char **ppc)
{
	char **p = ppc;
	while (*p) {
		free(*p);
		p++;
	}
	free (ppc);
	return 0;
}

int myclass(char **Selected_Classes, int long_listing)
{
	int rc, obj_count, err_code;
	LL_element *queryObject, *a_class;

	char *class_name = NULL; 
	int available_slots;
	int maximum_slots;
	int class_contraints;
	char *class_comment = NULL;
	int class_sysprio;
	char **exclude_users = NULL;
	char **include_users = NULL;
	char **exclude_groups = NULL;
	char **include_groups = NULL;
	char **class_admins = NULL;
	int class_max_node;
	int class_maxjobs;
	char *class_ckpt_dir = NULL;
	int64_t	class_ckpt_time_limit;
	int64_t	class_ckpt_soft_time_limit;
	int64_t	class_wall_clock_limit;
	int64_t	class_wall_clock_soft_limit;
	int64_t	class_job_cpu_limit;
	int64_t	class_job_cpu_soft_limit;
	int64_t	class_cpu_limit;
	int64_t	class_cpu_soft_limit;
	int64_t	class_data_limit;
	int64_t	class_data_soft_limit;
	int64_t class_as_limit;
	int64_t class_as_soft_limit;
	int64_t class_nproc_limit;
	int64_t class_nproc_soft_limit;
	int64_t class_memlock_limit;
	int64_t class_memlock_soft_limit;
	int64_t class_locks_limit;
	int64_t class_locks_soft_limit;
	int64_t class_nofile_limit;
	int64_t class_nofile_soft_limit;
	int64_t	class_core_limit;
	int64_t	class_core_soft_limit;
	int64_t	class_file_limit;
	int64_t	class_file_soft_limit;
	int64_t	class_stack_limit;
	int64_t	class_stack_soft_limit;
	int64_t	class_rss_limit;
	int64_t	class_rss_soft_limit;
	int class_nice;
	int class_max_total_tasks;
	char *preempt_class_rule_rhs = NULL;
	char *start_class_rule_rhs = NULL;
	int class_max_protocol_instances = 0;
	LL_element *consumable_res_req;
	char *consumable_res_req_name = NULL;
	int64_t consumable_res_req_value;

	/* Initialize the CLASSES query */
	queryObject = ll_query(CLASSES);
	if (!queryObject) {
		printf("ll_query(CLASSES) returned NULL\n");
		return(-1);
	}

	/* Set query parameters */
	if (Selected_Classes) {
		rc = ll_set_request(queryObject, QUERY_CLASS, Selected_Classes, ALL_DATA);
	} else {
		rc = ll_set_request(queryObject, QUERY_ALL, NULL, ALL_DATA);
	}
	if (rc) {
		printf("ll_set_request returned %d\n", rc);
		return(-1);
	}

	/* Get the requested a_class from the central manager daemon */
	a_class = ll_get_objs(queryObject, LL_CM, NULL, &obj_count, &err_code);
	if (err_code) {
		printf("ll_get_objs failed with err_code %d.\n", err_code);
		return(-1);
	}
	if (obj_count < 1) { 
		return(0);
	}

	if (!long_listing) {
		/* Display the banner of short output listing. */
		printf("Name                 MaxJobCPU     MaxProcCPU  Free   Max  Description\n");
		printf("                    d+hh:mm:ss     d+hh:mm:ss Slots Slots\n");
		printf("--------------- -------------- -------------- ----- -----  ---------------------\n");
	}

	while (a_class) {
		rc = ll_get_data(a_class, LL_ClassName, &class_name);

		rc = ll_get_data(a_class, LL_ClassConstraints, &class_contraints);

		rc = ll_get_data(a_class, LL_ClassCpuStepLimitHard, &class_job_cpu_limit);
		rc = ll_get_data(a_class, LL_ClassCpuLimitHard, &class_cpu_limit);
		rc = ll_get_data(a_class, LL_ClassFreeSlots, &available_slots);
		rc = ll_get_data(a_class, LL_ClassMaximumSlots, &maximum_slots);
		rc = ll_get_data(a_class, LL_ClassComment, &class_comment);
		
		if (!long_listing) {
			/* Short format. Show key information associated with this class on 1 line. */
			printf("%-15.15s %14lld %14lld %5d %5d %s\n", 
				class_name, class_job_cpu_limit, class_cpu_limit, 
				available_slots, maximum_slots, class_comment);
			a_class = ll_next_obj(queryObject);
			continue;   /* Go to next class. */
		}

		/* Long format. One line (mostly) for each parameter of this class. */


		printf("=============== Class %s ===============\n", STR_NULL(class_name));

		/* Class Name */
		printf("                Name: %s\n", STR_NULL(class_name));

		/* Class Priority */
		rc = ll_get_data(a_class, LL_ClassPriority, &class_sysprio);
		printf("            Priority: %d\n", class_sysprio);

		/* Include or Exclude users. */
		rc = ll_get_data(a_class, LL_ClassExcludeUsers, &exclude_users);
		printf("       Exclude_Users:");
		print_strings(exclude_users);

		rc = ll_get_data(a_class, LL_ClassIncludeUsers, &include_users);
		printf("       Include_Users:");
		print_strings(include_users);

		/* Exclude or Include Groups. */
		rc = ll_get_data(a_class, LL_ClassExcludeGroups, &exclude_groups);
		printf("      Exclude_Groups:");
		print_strings(exclude_groups);
		rc = ll_get_data(a_class, LL_ClassIncludeGroups, &include_groups);
		printf("      Include_Groups:");
		print_strings(include_groups);

		/* List of administrators of this class */
		rc = ll_get_data(a_class, LL_ClassAdmin, &class_admins);
		printf("               Admin:");
		print_strings(class_admins);

		/* Max_node */
		rc = ll_get_data(a_class, LL_ClassMaxNode, &class_max_node);
		printf("            Max_node: %d\n", class_max_node);

		/* Maxjobs */
		rc = ll_get_data(a_class, LL_ClassMaxJobs, &class_maxjobs);
		printf("             Maxjobs: %d\n", class_maxjobs);

		/* Consumable Resource Requirements. */
		printf("Resource_requirement:");
		rc = ll_get_data(a_class, LL_ClassGetFirstResourceRequirement, &consumable_res_req);
		while (consumable_res_req) {
			rc = ll_get_data(consumable_res_req, LL_ResourceRequirementName, &consumable_res_req_name);
			rc = ll_get_data(consumable_res_req, LL_ResourceRequirementValue64, &consumable_res_req_value);
			printf(" %s(%lld)", consumable_res_req_name, consumable_res_req_value);
			free(consumable_res_req_name);
			consumable_res_req_name = NULL;
			rc = ll_get_data(a_class, LL_ClassGetNextResourceRequirement, &consumable_res_req);
		}
		printf("\n");
			
		/* Class Comment */
		printf("       Class_comment: %s\n", class_comment);

		/* Class Checkpoint Directory */
		rc = ll_get_data(a_class, LL_ClassCkptDir, &class_ckpt_dir);
		printf("      Class_ckpt_dir: %s\n", STR_NULL(class_ckpt_dir));

		/* Checkpoint limits */
		rc = ll_get_data(a_class, LL_ClassCkptTimeHardLimit, &class_ckpt_time_limit);
		rc = ll_get_data(a_class, LL_ClassCkptTimeSoftLimit, &class_ckpt_soft_time_limit);
		printf("          Ckpt_limit: %lld,%lld\n", 
			class_ckpt_time_limit, class_ckpt_soft_time_limit);

		/* Wall clock limits */
		rc = ll_get_data(a_class, LL_ClassWallClockLimitHard, &class_wall_clock_limit);
		rc = ll_get_data(a_class, LL_ClassWallClockLimitSoft, &class_wall_clock_soft_limit);
		printf("    Wall_clock_limit: %lld,%lld\n", 
			class_wall_clock_limit, class_wall_clock_soft_limit);

		/* Job CPU limits */
		rc = ll_get_data(a_class, LL_ClassCpuStepLimitHard, &class_job_cpu_limit);
		rc = ll_get_data(a_class, LL_ClassCpuStepLimitSoft, &class_job_cpu_soft_limit);
		printf("       Job_cpu_limit: %lld,%lld\n",
			class_job_cpu_limit, class_job_cpu_soft_limit);

		/* CPU limits */
		rc = ll_get_data(a_class, LL_ClassCpuLimitHard, &class_cpu_limit);
		rc = ll_get_data(a_class, LL_ClassCpuLimitSoft, &class_cpu_soft_limit);
		printf("           Cpu_limit: %lld,%lld\n",
			class_cpu_limit, class_cpu_soft_limit);

		/* Data limits */
		rc = ll_get_data(a_class, LL_ClassDataLimitHard, &class_data_limit);
		rc = ll_get_data(a_class, LL_ClassDataLimitSoft, &class_data_soft_limit);
		printf("          Data_limit: %lld,%lld\n",
			class_data_limit, class_data_soft_limit);

		/* As limits */
		rc = ll_get_data(a_class, LL_ClassAsLimitHard, &class_as_limit);
		rc = ll_get_data(a_class, LL_ClassAsLimitSoft, &class_as_soft_limit);
		printf("            As_limit: %lld,%lld\n",
			class_as_limit, class_as_soft_limit);

		/* Nproc limits */
		rc = ll_get_data(a_class, LL_ClassNprocLimitHard, &class_nproc_limit);
		rc = ll_get_data(a_class, LL_ClassNprocLimitSoft, &class_nproc_soft_limit);
		printf("         Nproc_limit: %lld,%lld\n",
			class_nproc_limit, class_nproc_soft_limit);

		/* Memlock limits */
		rc = ll_get_data(a_class, LL_ClassMemlockLimitHard, &class_memlock_limit);
		rc = ll_get_data(a_class, LL_ClassMemlockLimitSoft, &class_memlock_soft_limit);
		printf("       Memlock_limit: %lld,%lld\n",
			class_memlock_limit, class_memlock_soft_limit);

		/* Locks limits */
		rc = ll_get_data(a_class, LL_ClassLocksLimitHard, &class_locks_limit);
		rc = ll_get_data(a_class, LL_ClassLocksLimitSoft, &class_locks_soft_limit);
		printf("         Locks_limit: %lld,%lld\n",
			class_locks_limit, class_locks_soft_limit);

		/* Nofile limits */
		rc = ll_get_data(a_class, LL_ClassNofileLimitHard, &class_nofile_limit);
		rc = ll_get_data(a_class, LL_ClassNofileLimitSoft, &class_nofile_soft_limit);
		printf("        Nofile_limit: %lld,%lld\n",
			class_nofile_limit, class_nofile_soft_limit);
		
		/* Core limits */
		rc = ll_get_data(a_class, LL_ClassCoreLimitHard, &class_core_limit);
		rc = ll_get_data(a_class, LL_ClassCoreLimitSoft, &class_core_soft_limit);
		printf("          Core_limit: %lld,%lld\n",
			class_core_limit, class_core_soft_limit);

		/* File limits */
		rc = ll_get_data(a_class, LL_ClassFileLimitHard, &class_file_limit);
		rc = ll_get_data(a_class, LL_ClassFileLimitSoft, &class_file_soft_limit);
		printf("          File_limit: %lld,%lld\n",
			class_file_limit, class_file_soft_limit);

		/* Stack limits */
		rc = ll_get_data(a_class, LL_ClassStackLimitHard, &class_stack_limit);
		rc = ll_get_data(a_class, LL_ClassStackLimitSoft, &class_stack_soft_limit);
		printf("         Stack_limit: %lld,%lld\n",
			class_stack_limit, class_stack_soft_limit);

		/* Rss limits */
		rc = ll_get_data(a_class, LL_ClassRssLimitHard, &class_rss_limit);
		rc = ll_get_data(a_class, LL_ClassRssLimitSoft, &class_rss_soft_limit);
		printf("           Rss_limit: %lld,%lld\n",
			class_rss_limit, class_rss_soft_limit);

		/* Nice Priority */
		rc = ll_get_data(a_class, LL_ClassNice, &class_nice);
		printf("                Nice: %d\n", class_nice);

		/* Free "slots" */
		printf("          Free_slots: %d\n", available_slots);

		/* Maximum "slots" */
		printf("       Maximum_slots: %d\n", maximum_slots);

		/* Maximum Total Tasks */
		rc = ll_get_data(a_class, LL_ClassMaxTotalTasks, &class_max_total_tasks);
		printf("     Max_total_tasks: %d\n", class_max_total_tasks);

		/* MaxProtocolInstances */
		rc = ll_get_data(a_class, LL_ClassMaxProtocolInstances, &class_max_protocol_instances);
		printf(" Max_proto_instances: %d\n", class_max_protocol_instances);

		/* get PREEMPT_CLASS[class] and START_CLASS[class] rules */

		/* PREEMPT_CLASS[class] */
		rc = ll_get_data(a_class, LL_ClassPreemptClass, &preempt_class_rule_rhs);
		printf("       Preempt_class: %s\n", STR_NULL(preempt_class_rule_rhs));

		/* START_CLASS[class] */
		rc = ll_get_data(a_class, LL_ClassStartClass, &start_class_rule_rhs);
		printf("         Start_class: %s\n", STR_NULL(start_class_rule_rhs));
		
		/* constraints */
		if (class_contraints & MAXIMUM_SLOTS_LIMITED_BY_MAX_STARTERS) {
			printf("\"Mximum Slots\" value of class \"%s\" is constrained by the MAX_STARTERS limit(s).\n", class_name);
		}
		if (class_contraints & FREE_SLOTS_LIMITED_BY_MAX_STARTERS) {
			printf("\"Free Slots\" value of class \"%s\" is constrained by the MAX_STARTERS limit(s).\n", class_name);
		}
		if (class_contraints & FREE_SLOTS_LIMITED_BY_MAX_JOBS) {
			printf("\"Free Slots\" value of class \"%s\" is constrained by the MAXJOBS limit(s).\n", class_name);
		}

		free(class_name);
		free(class_comment);
		free(class_ckpt_dir);
		free(preempt_class_rule_rhs);
		free(start_class_rule_rhs);
		free_strings(exclude_users);
		free_strings(include_users);
		free_strings(exclude_groups);
		free_strings(include_groups);
		free_strings(class_admins);
		class_name = NULL; 
		class_comment = NULL;
		exclude_users = NULL;
		include_users = NULL;
		exclude_groups = NULL;
		include_groups = NULL;
		class_admins = NULL;
		class_ckpt_dir = NULL;
		preempt_class_rule_rhs = NULL;
		start_class_rule_rhs = NULL;

		/* get next class */
		a_class = ll_next_obj(queryObject);
	}

	ll_free_objs(queryObject);
	ll_deallocate(queryObject);

	return 0;
}

int main(int argc, char *argv[])
{
	int opt;
	int long_listing = 0;
	int config_loop = 0;

	char **Selected_Classes = NULL;

	/* Parsing command line arguments */
	while ( (opt = getopt(argc, argv, "lr")) != EOF) 
	{
		switch (opt) 
		{
			case 'l':
				long_listing = 1;
				break;
			case 'r':
				config_loop = 1;
				break;
			default:
				usage();
				return(-1);
		}
	}
	if (argv[optind] != NULL)
	{
		Selected_Classes = &argv[optind];
	}

	myclass(Selected_Classes, long_listing);

	/*
	 *  endless loop if -r option is specified,
	 *  Ctrl-C to break out the program.
	 */
	while (config_loop) {
		printf("\n>>>>>>>>>>>>>>>>>>>> sleep 15 seconds <<<<<<<<<<<<<<<<<<<\n\n");
		sleep(15);

		/*
		 * Read the configuration files if they were changes
		 * since the last time they were read.
		 */
		if(ll_config_changed())
		{
			/*
		 	 * Yes, the configuration files were changed since last read!
			 */
			LL_element *errObj = NULL; /* Error information from the API */
		
			printf(">>>> !!!! config changed !!!! <<<<\n");

			/* re-read the configuration files. */
			if (ll_read_config(&errObj) != API_OK) {
				/*
				 * Error processing with ll_error() API.
				 * Pls refer to the LoadLeveler Using and Administering Guide
				 */
				if (errObj) ll_error(&errObj, 1);
			}
		}

		/* call other LoadLeveler APIs */
		myclass(Selected_Classes, long_listing);
	}

	return (0);
}

