/*======================================================================*/
/*                                                                      */
/* Module Name: wlmstat.c                                               */
/*                                                                      */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* Description: This sample program uses the Data Access API to query   */
/* the WLMSTAT object for all running jobs.				*/
/*                                                                      */
/*======================================================================*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "llapi.h"

main(int argc,char *argv[]) {
	LL_element *qj=NULL, *job=NULL;
	LL_element *qw=NULL, *wlm=NULL;
	int rc, num, err, state;
	time_t time;
	LL_element *step=NULL, *machine = NULL;
	char *id=NULL, *name=NULL;
	int cpu_snapshot, memory_snapshot, lpmemory_snapshot;
	int64_t memory_highwater, cpu_total, vmemory_highwater, vmemory_snapshot;
	char *stepid[2] = {NULL, NULL};

	/* Initialize the query for jobs */
	qj = ll_query(JOBS);
	if (qj) {
		printf("ll_query(JOBS) successful.\n");
	}

	/* I want to query all jobs */
	rc = ll_set_request(qj,QUERY_ALL,NULL,(enum DataFilter)NULL);
	printf("ll_set_request rc = %d.\n",rc);

	/* Request the objects from the Negotiator daemon */
	job = ll_get_objs(qj,LL_CM,NULL,&num,&err);
	printf("ll_get_objs rc = %d.\n",rc);

	/* Did we get a list of jobs ? */
	if (job == NULL) {
		printf("  ll_get_objs returned a NULL job.\n");
		printf("  err = %d\n",err);
	} else {
		/* Loop through the list and process */
		printf(" RESULT: number of jobs in list = %d\n",num);
		while(job) {
			rc = ll_get_data(job,LL_JobGetFirstStep, &step);
			while (step) {
				rc = ll_get_data(step,LL_StepID, &id);
				rc = ll_get_data(step,LL_StepState,&state);
				printf(" RESULT: step id: %s\n",id);
				stepid[0] = strdup(id);
				if (state == STATE_RUNNING) {
					qw = ll_query(WLMSTAT);
					if (qw) {
						printf("  ll_query(WLMSTAT) successful\n");
					}
					rc = ll_set_request(qw,QUERY_STEPID,stepid,(enum DataFilter)NULL);
					printf("  ll_set_request rc = %d \n",rc);

					rc = ll_get_data(step,LL_StepGetFirstMachine, &machine);
					while(machine) {
						rc = ll_get_data(machine,LL_MachineName, &name);
						/* Get info from Startd on this machine */
						wlm = ll_get_objs(qw,LL_STARTD,name,&num,&err);
						printf("  ll_get_objs rc = %d \n",rc);
						if (wlm) {
							rc = ll_get_data(wlm,LL_WlmStatCpuTotalUsage, &cpu_total);
							printf("  RESULT: cpu_total: %lld\n",cpu_total);
							rc = ll_get_data(wlm,LL_WlmStatCpuSnapshotUsage, &cpu_snapshot);
							printf("  RESULT: cpu_snapshot: %d\n",cpu_snapshot);
							rc = ll_get_data(wlm,LL_WlmStatMemorySnapshotUsage, &memory_snapshot);
							printf("  RESULT: memory_snapshot: %d\n",memory_snapshot);
							rc = ll_get_data(wlm,LL_WlmStatMemoryHighWater, &memory_highwater);
							printf("  RESULT: memory_highwater: %lld\n",memory_highwater);
							rc = ll_get_data(wlm,LL_WlmStatVMemorySnapshotUsage, &vmemory_snapshot);
							printf("  RESULT: virtual_memory_snapshot: %lld\n",vmemory_snapshot);
							rc = ll_get_data(wlm,LL_WlmStatVMemoryHighWater, &vmemory_highwater);
							printf("  RESULT: virtual_memory_highwater: %lld\n",vmemory_highwater);
							rc = ll_get_data(wlm,LL_WlmStatLargePageMemorySnapshotUsage, &lpmemory_snapshot);
							printf("  RESULT: large_page_snapshot: %d\n",lpmemory_snapshot);

							rc = ll_free_objs(qw);
						} /* if wlm */
						else {
							printf("  RESULT: No WLM object returned.\n");
						}
						rc = ll_deallocate(qw);
						rc = ll_get_data(step,LL_StepGetNextMachine, &machine);
					} /* while machine */
				} else {
					printf("  Not Running.\n");
				}
				if (id) free(id);
				if (stepid[0]) free(stepid[0]);
				rc=ll_get_data(job,LL_JobGetNextStep,&step);
			}
			job = ll_next_obj(qj);
		}
	}

	/* free jobs obtained from Negotiator */
	rc = ll_free_objs(qj);

	/* free query element */
	rc = ll_deallocate(qj);
}

